@@ -96,17 +96,18 @@ CCDSim::CCDSim()
     AbortPrimaryFrame = false;
     ShowStarField=true;
 
-    Capability cap;
+    CCDCapability cap;
 
     cap.canAbort = true;
     cap.canBin = true;
     cap.canSubFrame = true;
-    cap.hasCooler = false;
+    cap.hasCooler = true;
     cap.hasGuideHead = true;
     cap.hasShutter = true;
     cap.hasST4Port = true;
+    cap.hasBayer = false;
 
-    SetCapability(&cap);
+    SetCCDCapability(&cap);
 
     polarError=0;
     polarDrift=0;
@@ -154,6 +155,12 @@ bool CCDSim::SetupParms()
     int nbuf;
     SetCCDParams(SimulatorSettingsN[0].value,SimulatorSettingsN[1].value,16,SimulatorSettingsN[2].value,SimulatorSettingsN[3].value);
 
+    if (HasCooler())
+    {
+        TemperatureN[0].value = 20;
+        IDSetNumber(&TemperatureNP, NULL);
+    }
+
     //  Kwiq
     maxnoise=SimulatorSettingsN[8].value;
     skyglow=SimulatorSettingsN[9].value;
@@ -228,13 +235,17 @@ bool CCDSim::initProperties()
     IUFillNumber(&ScopeParametersN[3],"GUIDER_FOCAL_LENGTH","Guider Focal Length (mm)","%g",100,10000,0,0.0 );
     IUFillNumberVector(&ScopeParametersNP,ScopeParametersN,4,ActiveDeviceT[0].text,"TELESCOPE_INFO","Scope Properties",OPTIONS_TAB,IP_RW,60,IPS_OK);
 
+    IUFillSwitch(&CoolerS[0], "COOLER_ON", "ON", ISS_OFF);
+    IUFillSwitch(&CoolerS[1], "COOLER_OFF", "OFF", ISS_ON);
+    IUFillSwitchVector(&CoolerSP, CoolerS, 2, getDeviceName(), "CCD_COOLER", "Cooler", MAIN_CONTROL_TAB, IP_WO, ISR_1OFMANY, 0, IPS_IDLE);
+
     IUFillNumber(&EqPEN[0],"RA_PE","RA (hh:mm:ss)","%010.6m",0,24,0,0);
     IUFillNumber(&EqPEN[1],"DEC_PE","DEC (dd:mm:ss)","%010.6m",-90,90,0,0);
     IUFillNumberVector(&EqPENP,EqPEN,2,ActiveDeviceT[0].text,"EQUATORIAL_PE","EQ PE","Main Control",IP_RW,60,IPS_IDLE);
 
     IDSnoopDevice(ActiveDeviceT[0].text,"EQUATORIAL_PE");
     IDSnoopDevice(ActiveDeviceT[0].text,"TELESCOPE_INFO");
-    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");
+    IDSnoopDevice(ActiveDeviceT[1].text,"FWHM");       
 
     initFilterProperties(getDeviceName(), FILTER_TAB);
 
@@ -243,6 +254,8 @@ bool CCDSim::initProperties()
 
     addDebugControl();
 
+    setInterfaceDescriptor(getInterfaceDescriptor() | FILTER_INTERFACE);
+
     return true;
 }
 
@@ -265,6 +278,9 @@ bool CCDSim::updateProperties()
 
     if (isConnected())
     {
+        if (HasCooler())
+            defineSwitch(&CoolerSP);
+
         SetupParms();
 
         if(HasGuideHead())
@@ -279,6 +295,9 @@ bool CCDSim::updateProperties()
             defineText(FilterNameTP);
     } else
     {
+        if (HasCooler())
+            deleteProperty(CoolerSP.name);
+
         deleteProperty(FilterSlotNP.name);
         deleteProperty(FilterNameTP->name);
     }
@@ -292,6 +311,22 @@ bool CCDSim::Disconnect()
     return true;
 }
 
+int CCDSim::SetTemperature(double temperature)
+{
+    TemperatureRequest = temperature;
+    if (fabs(temperature - TemperatureN[0].value) < 0.1)
+    {
+            TemperatureN[0].value = temperature;
+            return 1;
+    }
+
+    CoolerS[0].s = ISS_ON;
+    CoolerS[1].s = ISS_OFF;
+    CoolerSP.s = IPS_BUSY;
+    IDSetSwitch(&CoolerSP, NULL);
+    return 0;
+}
+
 bool CCDSim::StartExposure(float duration)
 {
     //  for the simulator, we can just draw the frame now
@@ -433,6 +468,35 @@ void CCDSim::TimerHit()
             }
         }
     }
+
+    if (TemperatureNP.s == IPS_BUSY)
+    {
+        if (fabs(TemperatureRequest - TemperatureN[0].value) <= 0.5)
+        {
+            DEBUGF(INDI::Logger::DBG_SESSION, "Temperature reached requested value %.2f degrees C", TemperatureRequest);
+            TemperatureN[0].value = TemperatureRequest;
+            TemperatureNP.s = IPS_OK;
+        }
+        else
+        {
+            if (TemperatureRequest < TemperatureN[0].value)
+                TemperatureN[0].value -= 0.5;
+            else
+                TemperatureN[0].value += 0.5;
+        }
+
+        IDSetNumber(&TemperatureNP, NULL);
+
+        // Above 20, cooler is off
+        if (TemperatureN[0].value >= 20)
+        {
+            CoolerS[0].s = ISS_OFF;
+            CoolerS[0].s = ISS_ON;
+            CoolerSP.s = IPS_IDLE;
+            IDSetSwitch(&CoolerSP, NULL);
+        }
+    }
+
     SetTimer(nexttimer);
     return;
 }
@@ -520,7 +584,8 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         pa=targetFocalLength/targetChip->getPixelSizeX()*1000/targetChip->getBinX();
         pe=targetFocalLength/targetChip->getPixelSizeY()*1000/targetChip->getBinY();
 
-        //IDLog("Pixels are %4.2f %4.2f  pa %6.4f  pe %6.4f\n",PixelSizex,PixelSizey,pa,pe);
+        //IDLog("Focal length is %6.4f Pixels are %4.2f %4.2f  pa %6.4f  pe %6.4f\n",targetFocalLength,
+	//      targetChip->getPixelSizeX(), targetChip->getPixelSizeY(),pa,pe);
 
         //  these numbers are now pixels per radian
         float Scalex;
@@ -567,7 +632,7 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         // Add declination drift, if any.
         decr += decDrift/3600.0 * 0.0174532925;
 
-        //fprintf(stderr,"decPE %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",decPE,cameradec,CenterOffsetDec);
+        //fprintf(stderr,"decPE %7.5f  cameradec %7.5f  CenterOffsetDec %4.4f\n",decPE,cameradec,decr);
         //  now lets calculate the radius we need to fetch
         float radius;
 
@@ -601,10 +666,11 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
         CCDChip::CCD_FRAME ftype = targetChip->getFrameType();
 
         if (ftype==CCDChip::LIGHT_FRAME)
-        {
+        {  
+            setlocale(LC_NUMERIC,"C");
             //sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r 120 -m 0 9.1",rad+PEOffset,decPE);
             sprintf(gsccmd,"gsc -c %8.6f %+8.6f -r %4.1f -m 0 %4.2f -n 3000",rad+PEOffset,cameradec,radius,lookuplimit);
-            //fprintf(stderr,"gsccmd %s\n",gsccmd);
+            fprintf(stderr,"%s\n",gsccmd);
             pp=popen(gsccmd,"r");
             if(pp != NULL) {
                 char line[256];
@@ -672,10 +738,12 @@ int CCDSim::DrawCcdFrame(CCDChip *targetChip)
                     }
                 }
                 pclose(pp);
+		setlocale(LC_NUMERIC,"");
             } else
             {
                 IDMessage(getDeviceName(),"Error looking up stars, is gsc installed with appropriate environment variables set ??");
                 //fprintf(stderr,"Error doing gsc lookup\n");
+		setlocale(LC_NUMERIC,"");
             }
             if(drawn==0)
             {
@@ -952,6 +1020,23 @@ bool CCDSim::GuideWest(float v)
     return true;
 }
 
+bool CCDSim::ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int n)
+{
+    if(strcmp(dev,getDeviceName())==0)
+    {
+        //  This is for our device
+        //  Now lets see if it's something we process here
+        if(strcmp(name,FilterNameTP->name)==0)
+        {
+            processFilterName(dev, texts, names, n);
+            return true;
+        }
+
+    }
+
+    return INDI::CCD::ISNewText(dev,name,texts,names,n);
+}
+
 bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n)
 {
     //  first check if it's for our device
@@ -970,7 +1055,6 @@ bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], ch
             //  Reset our parameters now
             SetupParms();
             IDSetNumber(SimulatorSettingsNV,NULL);
-            saveConfig();
 
             //IDLog("Frame set to %4.0f,%4.0f %4.0f x %4.0f\n",CcdFrameN[0].value,CcdFrameN[1].value,CcdFrameN[2].value,CcdFrameN[3].value);
             //seeing=SimulatorSettingsN[0].value;
@@ -993,16 +1077,11 @@ bool CCDSim::ISNewNumber (const char *dev, const char *name, double values[], ch
 
 bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
-    //IDLog("Enter IsNewSwitch for %s\n",name);
-    //for(int x=0; x<n; x++) {
-    //    IDLog("Switch %s %d\n",names[x],states[x]);
-    //}
 
-    if(strcmp(dev,getDeviceName())==0) {
-        //  This one is for us
-
-
-        if(strcmp(name,"ON_TIME_FACTOR")==0) {
+    if(strcmp(dev,getDeviceName())==0)
+    {
+        if(strcmp(name,"ON_TIME_FACTOR")==0)
+        {
 
             //  client is telling us what to do with co-ordinate requests
             TimeFactorSV->s=IPS_OK;
@@ -1010,7 +1089,6 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
             //  Update client display
             IDSetSwitch(TimeFactorSV,NULL);
 
-            saveConfig();
             if(TimeFactorS[0].s==ISS_ON    ) {
                 //IDLog("CCDSim:: Time Factor 1\n");
                 TimeFactor=1;
@@ -1029,6 +1107,24 @@ bool CCDSim::ISNewSwitch (const char *dev, const char *name, ISState *states, ch
 
     }
 
+    if (!strcmp(name, CoolerSP.name))
+    {
+        IUUpdateSwitch(&CoolerSP, states, names, n);
+
+        if (CoolerS[0].s == ISS_ON)
+            CoolerSP.s = IPS_BUSY;
+        else
+        {
+            CoolerSP.s = IPS_IDLE;
+            TemperatureRequest = 20;
+            TemperatureNP.s = IPS_BUSY;
+        }
+
+        IDSetSwitch(&CoolerSP, NULL);
+
+        return true;
+    }
+
     //  Nobody has claimed this, so, ignore it
     return INDI::CCD::ISNewSwitch(dev,name,states,names,n);
 }
@@ -1131,7 +1227,7 @@ bool CCDSim::GetFilterNames(const char* groupName)
     for (int i=0; i < MaxFilter; i++)
     {
         snprintf(filterName, MAXINDINAME, "FILTER_SLOT_NAME_%d", i+1);
-        snprintf(filterLabel, MAXINDILABEL, "Filter #%d", i+1);
+        snprintf(filterLabel, MAXINDILABEL, "Filter#%d", i+1);
         IUFillText(&FilterNameT[i], filterName, filterLabel, filterDesignation[i]);
     }
 
