@@ -92,7 +92,15 @@ void ISSnoopDevice (XMLEle *root)
 
 FocusSim::FocusSim()
 {
-    setFocuserFeatures(true, false, false, true);
+    ticks=0;
+
+    FocuserCapability cap;
+    cap.canAbort=true;
+    cap.canAbsMove=true;
+    cap.canRelMove=true;
+    cap.variableSpeed=true;
+
+    SetFocuserCapability(&cap);
 
 }
 
@@ -120,8 +128,6 @@ const char * FocusSim::getDefaultName()
 
 bool FocusSim::initProperties()
 {
-    //  Most hardware layers wont actually have indi properties defined
-    //  but the simulators are a special case
     INDI::Focuser::initProperties();
 
     IUFillNumber(&SeeingN[0],"SIM_SEEING","arcseconds","%4.2f",0,60,0,3.5);
@@ -132,22 +138,9 @@ bool FocusSim::initProperties()
 
     ticks = initTicks = sqrt(FWHMN[0].value - SeeingN[0].value) / 0.75;
 
-    if (isDebug())
-        IDLog("Initial Ticks is %g\n", ticks);
-
     return true;
 }
 
-void FocusSim::ISGetProperties (const char *dev)
-{
-    //  First we let our parent populate
-    INDI::Focuser::ISGetProperties(dev);
-
-
-
-    return;
-}
-
 bool FocusSim::updateProperties()
 {
 
@@ -155,14 +148,12 @@ bool FocusSim::updateProperties()
 
     if (isConnected())
     {
-        defineNumber(&FocusAbsPosNP);
         defineNumber(&SeeingNP);
         defineNumber(&FWHMNP);
         SetupParms();
     }
     else
     {
-        deleteProperty(FocusAbsPosNP.name);
         deleteProperty(SeeingNP.name);
         deleteProperty(FWHMNP.name);
     }
@@ -197,8 +188,6 @@ bool FocusSim::ISNewNumber (const char *dev, const char *name, double values[],
             IUUpdateNumber(&SeeingNP, values, names, n);
 
             IDSetNumber(&SeeingNP,NULL);
-            saveConfig();
-
             return true;
 
         }
@@ -218,7 +207,7 @@ bool FocusSim::ISNewSwitch (const char *dev, const char *name, ISState *states,
     return INDI::Focuser::ISNewSwitch(dev,name,states,names,n);
 }
 
-int FocusSim::Move(FocusDirection dir, int speed, int duration)
+int FocusSim::MoveFocuser(FocusDirection dir, int speed, int duration)
 {
     double targetTicks = (speed * duration) / (FocusSpeedN[0].max * FocusTimerN[0].max);
     double plannedTicks=ticks;
@@ -259,7 +248,7 @@ int FocusSim::Move(FocusDirection dir, int speed, int duration)
 
 }
 
-int FocusSim::MoveAbs(int targetTicks)
+int FocusSim::MoveAbsFocuser(int targetTicks)
 {
     if (targetTicks < FocusAbsPosN[0].min || targetTicks > FocusAbsPosN[0].max)
     {
