@@ -51,9 +51,6 @@ class FocusSim : public INDI::Focuser
         bool initProperties();
         bool updateProperties();
 
-        void ISGetProperties (const char *dev);
-
-
         bool Connect();
         bool Disconnect();
 
@@ -62,8 +59,8 @@ class FocusSim : public INDI::Focuser
         virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
         virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
 
-        virtual int Move(FocusDirection dir, int speed, int duration);
-        virtual int MoveAbs(int ticks);
+        virtual int MoveFocuser(FocusDirection dir, int speed, int duration);
+        virtual int MoveAbsFocuser(int ticks);
 
 
 };
