@@ -85,13 +85,20 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 void ISSnoopDevice (XMLEle *root)
 {
      ISInit();
+     moonLite->ISSnoopDevice(root);
 }
 
 MoonLite::MoonLite()
 {
 
-    // Can move in Absolute & Relative motions, can Abort motion, and has variable speed.
-    setFocuserFeatures(true, true, true, true);
+    // Can move in Absolute & Relative motions, can AbortFocuser motion, and has variable speed.
+    FocuserCapability cap;
+    cap.canAbort=true;
+    cap.canAbsMove=true;
+    cap.canRelMove=true;
+    cap.variableSpeed=true;
+
+    SetFocuserCapability(&cap);
 
     lastPos = 0;
     lastTemperature = 0;
@@ -144,7 +151,7 @@ bool MoonLite::initProperties()
     FocusRelPosN[0].step = 1000;
 
     FocusAbsPosN[0].min = 0.;
-    FocusAbsPosN[0].max = 30000.;
+    FocusAbsPosN[0].max = 60000.;
     FocusAbsPosN[0].value = 0;
     FocusAbsPosN[0].step = 1000;
 
@@ -269,7 +276,7 @@ bool MoonLite::updateStepMode()
 {
     int nbytes_written=0, nbytes_read=0, rc=-1;
     char errstr[MAXRBUF];
-    char resp[3];
+    char resp[4];
 
     tcflush(PortFD, TCIOFLUSH);
 
@@ -348,7 +355,7 @@ bool MoonLite::updatePosition()
     int nbytes_written=0, nbytes_read=0, rc=-1;
     char errstr[MAXRBUF];
     char resp[5];
-    short pos=-1;
+    int pos=-1;
 
     tcflush(PortFD, TCIOFLUSH);
 
@@ -366,7 +373,7 @@ bool MoonLite::updatePosition()
         return false;
     }
 
-    rc = sscanf(resp, "%hX#", &pos);
+    rc = sscanf(resp, "%X#", &pos);
 
     if (rc > 0)
     {
@@ -528,7 +535,7 @@ bool MoonLite::reset()
 
 }
 
-bool MoonLite::Move(unsigned int position)
+bool MoonLite::MoveFocuser(unsigned int position)
 {
     int nbytes_written=0, rc=-1;
     char errstr[MAXRBUF];
@@ -556,11 +563,11 @@ bool MoonLite::Move(unsigned int position)
         return false;
     }
 
-    // Move to Position
+    // MoveFocuser to Position
     if ( (rc = tty_write(PortFD, ":FG#", 4, &nbytes_written)) != TTY_OK)
     {
         tty_error_msg(rc, errstr, MAXRBUF);
-        DEBUGF(INDI::Logger::DBG_ERROR, "Move error: %s.", errstr);
+        DEBUGF(INDI::Logger::DBG_ERROR, "MoveFocuser error: %s.", errstr);
         return false;
     }
 
@@ -761,7 +768,7 @@ void MoonLite::GetFocusParams ()
         IDSetSwitch(&StepModeSP, NULL);
 }
 
-bool MoonLite::SetSpeed(int speed)
+bool MoonLite::SetFocuserSpeed(int speed)
 {
     bool rc = false;
 
@@ -778,7 +785,7 @@ bool MoonLite::SetSpeed(int speed)
     return true;
 }
 
-int MoonLite::Move(FocusDirection dir, int speed, int duration)
+int MoonLite::MoveFocuser(FocusDirection dir, int speed, int duration)
 {
     if (speed != currentSpeed)
     {
@@ -793,27 +800,27 @@ int MoonLite::Move(FocusDirection dir, int speed, int duration)
     focusMoveRequest = duration/1000.0;
 
     if (dir == FOCUS_INWARD)
-        Move(0);
+        MoveFocuser(0);
     else
-        Move(FocusAbsPosN[0].value + MaxTravelN[0].value - 1);
+        MoveFocuser(FocusAbsPosN[0].value + MaxTravelN[0].value - 1);
 
     if (duration <= POLLMS)
     {
         usleep(POLLMS * 1000);
-        Abort();
+        AbortFocuser();
     }
 
     return 1;
 }
 
 
-int MoonLite::MoveAbs(int targetTicks)
+int MoonLite::MoveAbsFocuser(int targetTicks)
 {
     targetPos = targetTicks;
 
     bool rc = false;
 
-    rc = Move(targetPos);
+    rc = MoveFocuser(targetPos);
 
     if (rc == false)
         return -1;
@@ -823,7 +830,7 @@ int MoonLite::MoveAbs(int targetTicks)
     return 1;
 }
 
-int MoonLite::MoveRel(FocusDirection dir, unsigned int ticks)
+int MoonLite::MoveRelFocuser(FocusDirection dir, unsigned int ticks)
 {
     double newPosition=0;
     bool rc=false;
@@ -833,7 +840,7 @@ int MoonLite::MoveRel(FocusDirection dir, unsigned int ticks)
     else
         newPosition = FocusAbsPosN[0].value + ticks;
 
-    rc = Move(newPosition);
+    rc = MoveFocuser(newPosition);
 
     if (rc == false)
         return -1;
@@ -880,7 +887,7 @@ void MoonLite::TimerHit()
         {
             FocusTimerNP.s = IPS_OK;
             FocusTimerN[0].value = 0;
-            Abort();
+            AbortFocuser();
         }
         else
             FocusTimerN[0].value = remaining*1000.0;
@@ -908,7 +915,7 @@ void MoonLite::TimerHit()
 
 }
 
-bool MoonLite::Abort()
+bool MoonLite::AbortFocuser()
 {
     int nbytes_written;
     if (tty_write(PortFD, ":FQ#", 4, &nbytes_written) == TTY_OK)
