@@ -108,12 +108,19 @@ std::auto_ptr<RoboFocus> roboFocus(0);
  void ISSnoopDevice (XMLEle *root)
  {
      ISInit();
+     roboFocus->ISSnoopDevice(root);
  }
 
 
 RoboFocus::RoboFocus()
-{
-    setFocuserFeatures(true, true, true, false);
+{   
+    FocuserCapability cap;
+    cap.canAbort=true;
+    cap.canAbsMove=true;
+    cap.canRelMove=true;
+    cap.variableSpeed=false;
+
+    SetFocuserCapability(&cap);
 
 }
 
@@ -172,7 +179,7 @@ bool RoboFocus::initProperties()
     /* Relative and absolute movement */
     FocusRelPosN[0].min = -65000.;
     FocusRelPosN[0].max = 65000.;
-    FocusRelPosN[0].value = 0;
+    FocusRelPosN[0].value = 100;
     FocusRelPosN[0].step = 100;
 
     FocusAbsPosN[0].min = 0.;
@@ -180,7 +187,11 @@ bool RoboFocus::initProperties()
     FocusAbsPosN[0].value = 0;
     FocusAbsPosN[0].step = 10000;
 
+    simulatedTemperature=600.0;
+    simulatedPosition=20000;
+
     addDebugControl();
+    addSimulationControl();
 
     return true;
 
@@ -240,9 +251,14 @@ bool RoboFocus::Connect()
     char errorMsg[MAXRBUF];
     char firmeware[]="FV0000000";
 
-
-    if (isDebug())
-        IDLog("connecting to %s\n",PortT[0].text);
+    if (isSimulation())
+    {
+        SetTimer(POLLMS);
+        IDMessage(getDeviceName(), "Simulated Robofocus is online. Getting focus parameters...");
+        FocusAbsPosN[0].value = simulatedPosition;
+        updateRFFirmware(firmeware);
+        return true;
+    }
 
     if ( (connectrc = tty_connect(PortT[0].text, 9600, 8, 0, 1, &PortFD)) != TTY_OK)
     {
@@ -272,6 +288,13 @@ bool RoboFocus::Connect()
 
 bool RoboFocus::Disconnect()
 {
+
+    if (isSimulation())
+    {
+        IDMessage(getDeviceName(), "Simulated Robofocus is offline.");
+        return true;
+    }
+
     tty_disconnect(PortFD);
     IDMessage(getDeviceName(), "RoboFocus is offline.");
     return true;
@@ -352,6 +375,9 @@ int RoboFocus::SendCommand(char *rf_cmd)
   }
 
 
+  if (isSimulation())
+      return 0;
+
   tcflush(PortFD, TCIOFLUSH);
 
    if  ( (err_code = tty_write(PortFD, rf_cmd_cks, RF_MAX_CMD, &nbytes_written) != TTY_OK))
@@ -386,6 +412,9 @@ int RoboFocus::ReadResponse(char *buf, int nbytes, int timeout)
   int totalBytesRead = 0;
   int err_code;
 
+  if (isSimulation())
+      return 9;
+
   if (isDebug())
       IDLog("##########################################\n");
   while (totalBytesRead < nbytes)
@@ -478,12 +507,22 @@ int RoboFocus::updateRFPosition(double *value)
   char rf_cmd[32] ;
   int ret_read_tmp ;
 
+  if (isSimulation())
+  {
+      *value = simulatedPosition;
+      return 0;
+  }
+
   strcpy(rf_cmd, "FG000000" ) ;
 
   if ((ret_read_tmp= SendCommand(  rf_cmd)) < 0){
 
     return ret_read_tmp;
   }
+
+  if (isSimulation())
+      snprintf(rf_cmd, 32, "FD%6g", simulatedPosition);
+
    if (sscanf(rf_cmd, "FD%6f", &temp) < 1){
 
     return -1;
@@ -507,6 +546,8 @@ int RoboFocus::updateRFTemperature(double *value)
   if ((ret_read_tmp= SendCommand( rf_cmd)) < 0)
     return ret_read_tmp;
 
+  if (isSimulation())
+      snprintf(rf_cmd, 32, "FT%6g", simulatedTemperature);
 
   if (sscanf(rf_cmd, "FT%6f", &temp) < 1)
     return -1;
@@ -525,6 +566,9 @@ int RoboFocus::updateRFBacklash(double *value)
   int ret_read_tmp ;
   int sign= 0 ;
 
+  if (isSimulation())
+      return 0;
+
   if(*value== BACKLASH_READOUT) {
 
     strcpy(rf_cmd, "FB000000" ) ;
@@ -583,6 +627,9 @@ int RoboFocus::updateRFFirmware(char *rf_cmd)
   if ((ret_read_tmp= SendCommand( rf_cmd)) < 0)
     return ret_read_tmp;
 
+  if (isSimulation())
+      strcpy(rf_cmd, "SIM");
+
   return 0;
 }
 
@@ -592,6 +639,14 @@ int RoboFocus::updateRFMotorSettings(double *duty, double *delay, double *ticks)
   char rf_cmd[32] ;
   int ret_read_tmp ;
 
+  if (isSimulation())
+  {
+     *duty = 100;
+     *delay = 0;
+     *ticks = 0;
+     return 0;
+  }
+
   if(( *duty== 0 ) && (*delay== 0) && (*ticks== 0) ){
 
     strcpy(rf_cmd, "FC000000" ) ;
@@ -628,6 +683,13 @@ int RoboFocus::updateRFPositionRelativeInward(double *value)
   float temp ;
   rf_cmd[0]= 0 ;
 
+  if (isSimulation())
+  {
+      simulatedPosition+= *value;
+      *value = simulatedPosition;
+      return 0;
+  }
+
   if(*value > 9999) {
     sprintf( rf_cmd, "FI0%5d", (int) *value) ;
   } else if(*value > 999) {
@@ -659,6 +721,13 @@ int RoboFocus::updateRFPositionRelativeOutward(double *value)
   int ret_read_tmp ;
   float temp ;
 
+  if (isSimulation())
+  {
+      simulatedPosition-= *value;
+      *value = simulatedPosition;
+      return 0;
+  }
+
   rf_cmd[0]= 0 ;
 
   if(*value > 9999) {
@@ -693,6 +762,12 @@ int RoboFocus::updateRFPositionAbsolute(double *value)
   int ret_read_tmp ;
   float temp ;
 
+  if (isSimulation())
+  {
+      simulatedPosition = *value;
+      return 0;
+  }
+
   rf_cmd[0]= 0 ;
 
   if(*value > 9999) {
@@ -727,6 +802,11 @@ int RoboFocus::updateRFPowerSwitches(int s, int  new_sn, int *cur_s1LL, int *cur
   int i = 0 ;
 
 
+  if (isSimulation())
+  {
+      return 0;
+  }
+
     /* Get first the status */
     strcpy(rf_cmd_tmp, "FP000000" ) ;
 
@@ -781,6 +861,11 @@ int RoboFocus::updateRFMaxPosition(double *value)
   int ret_read_tmp ;
   char waste[1] ;
 
+  if (isSimulation())
+  {
+      return 0;
+  }
+
   if(*value== MAXTRAVEL_READOUT) {
 
     strcpy(rf_cmd, "FL000000" ) ;
@@ -833,6 +918,12 @@ int RoboFocus::updateRFSetPosition(double *value)
   char vl_tmp[6] ;
   int ret_read_tmp ;
 
+  if (isSimulation())
+  {
+      simulatedPosition= *value;
+      return 0;
+  }
+
   rf_cmd[0]=  'F' ;
   rf_cmd[1]=  'S' ;
   rf_cmd[2]=  '0' ;
@@ -1371,7 +1462,7 @@ void RoboFocus::GetFocusParams ()
 
 }
 
-int RoboFocus::Move(FocusDirection dir, int speed, int duration)
+int RoboFocus::MoveFocuser(FocusDirection dir, int speed, int duration)
 {
     INDI_UNUSED(speed);
     double pos=0;
@@ -1403,7 +1494,7 @@ int RoboFocus::Move(FocusDirection dir, int speed, int duration)
 }
 
 
-int RoboFocus::MoveAbs(int targetTicks)
+int RoboFocus::MoveAbsFocuser(int targetTicks)
 {
     int ret= -1 ;
     targetPos = targetTicks;
@@ -1442,7 +1533,7 @@ int RoboFocus::MoveAbs(int targetTicks)
     return 1;
 }
 
-int RoboFocus::MoveRel(FocusDirection dir, unsigned int ticks)
+int RoboFocus::MoveRelFocuser(FocusDirection dir, unsigned int ticks)
 {
       double cur_rpos=0 ;
       double new_rpos = 0 ;
@@ -1497,10 +1588,12 @@ int RoboFocus::MoveRel(FocusDirection dir, unsigned int ticks)
 }
 
 bool RoboFocus::saveConfigItems(FILE *fp)
-{
+{        
     IUSaveConfigText(fp, &PortTP);
     IUSaveConfigNumber(fp, &SettingsNP);
     IUSaveConfigNumber(fp, &SetBacklashNP);
+
+    return INDI::Focuser::saveConfigItems(fp);
 }
 
 void RoboFocus::TimerHit()
@@ -1535,7 +1628,7 @@ void RoboFocus::TimerHit()
 
 }
 
-bool RoboFocus::Abort()
+bool RoboFocus::AbortFocuser()
 {
     int nbytes_written;
     const char *buf = "\r";
