@@ -39,10 +39,10 @@ public:
     virtual void ISGetProperties(const char *dev);
     virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
     virtual bool ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n);
-    virtual int Move(FocusDirection dir, int speed, int duration);
-    virtual int MoveAbs(int ticks);
-    virtual int MoveRel(FocusDirection dir, unsigned int ticks);
-    virtual bool Abort();
+    virtual int MoveFocuser(FocusDirection dir, int speed, int duration);
+    virtual int MoveAbsFocuser(int ticks);
+    virtual int MoveRelFocuser(FocusDirection dir, unsigned int ticks);
+    virtual bool AbortFocuser();
     virtual void TimerHit();
 
 protected:
@@ -52,6 +52,8 @@ private:
 
     int PortFD;
     double targetPos;
+    double simulatedTemperature;
+    double simulatedPosition;
 
     unsigned char CheckSum(char *rf_cmd);
     unsigned char CalculateSum(char *rf_cmd);
