@@ -101,7 +101,8 @@ void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[],
 }
 void ISSnoopDevice (XMLEle *root) 
 {
-    INDI_UNUSED(root);
+    ISInit();
+    tcfs->ISSnoopDevice(root);
 }
 
 /****************************************************************
@@ -110,7 +111,13 @@ void ISSnoopDevice (XMLEle *root)
 *****************************************************************/
 TCFS::TCFS()
 {
-    setFocuserFeatures(true, true, false, false);
+    FocuserCapability cap;
+    cap.canAbort=false;
+    cap.canAbsMove=true;
+    cap.canRelMove=true;
+    cap.variableSpeed=false;
+
+    SetFocuserCapability(&cap);
 
     simulated_position    = 3000;
     simulated_temperature = 25.4;
@@ -433,7 +440,7 @@ bool TCFS::ISNewSwitch (const char *dev, const char *name, ISState *states, char
         if (!strcmp(target_active_switch->name, "FOCUS_MIN"))
         {
             targetTicks = currentPosition;
-            MoveRel(FOCUS_INWARD, currentPosition);
+            MoveRelFocuser(FOCUS_INWARD, currentPosition);
             IDSetSwitch(sProp, "Moving focuser to minimum position...");
         }
         // Center
@@ -451,7 +458,7 @@ bool TCFS::ISNewSwitch (const char *dev, const char *name, ISState *states, char
         {
             unsigned int delta = 0;
             delta = FocusAbsPosN[0].max - currentPosition;
-            MoveRel(FOCUS_OUTWARD, delta);
+            MoveRelFocuser(FOCUS_OUTWARD, delta);
             IDSetSwitch(sProp, "Moving focuser to maximum position %g...", FocusAbsPosN[0].max);
         }
         // Home
@@ -486,20 +493,20 @@ bool TCFS::ISNewSwitch (const char *dev, const char *name, ISState *states, char
     return INDI::Focuser::ISNewSwitch(dev, name, states, names, n);
 }
 
-int TCFS::MoveAbs(int ticks)
+int TCFS::MoveAbsFocuser(int ticks)
 {
     int delta=0;
 
     delta = ticks - currentPosition;
 
     if (delta < 0)
-        MoveRel(FOCUS_INWARD, (unsigned int) fabs(delta));
+        MoveRelFocuser(FOCUS_INWARD, (unsigned int) fabs(delta));
     else
-        MoveRel(FOCUS_OUTWARD, (unsigned int) fabs(delta));
+        MoveRelFocuser(FOCUS_OUTWARD, (unsigned int) fabs(delta));
 
 }
 
-int TCFS::MoveRel(FocusDirection dir, unsigned int ticks)
+int TCFS::MoveRelFocuser(FocusDirection dir, unsigned int ticks)
 {
 
     if (inAutoMode)
