@@ -46,13 +46,13 @@ class CelestronGPS : public INDI::Telescope
  virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
  virtual bool ISSnoopDevice(XMLEle *root);
 
- static void joystickHelper(const char * joystick_n, double mag, double angle);
- static void buttonHelper(const char * button_n, ISState state);
+ static void joystickHelper(const char * joystick_n, double mag, double angle, void *context);
+ static void buttonHelper(const char * button_n, ISState state, void *context);
 
 protected:
 
- virtual bool MoveNS(TelescopeMotionNS dir);
- virtual bool MoveWE(TelescopeMotionWE dir);
+ virtual bool MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command);
+ virtual bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command);
  virtual bool Abort();
 
  virtual bool updateLocation(double latitude, double longitude, double elevation);
@@ -62,8 +62,6 @@ protected:
 
  bool Goto(double ra,double dec);
  bool Sync(double ra, double dec);
- virtual bool canSync();
- virtual bool canPark();
 
  void slewError(int slewCode);
  void mountSim();
