@@ -26,13 +26,13 @@
 //#include "indidevapi.h"
 //#include "indicom.h"
 
-#include "lx200generic.h"
+#include "lx200genericlegacy.h"
 // To prevent of using mydev from generic by error
 #ifdef mydev
 #undef mydevice
 #endif
 
-class LX200Fs2 : public LX200Generic
+class LX200Fs2 : public LX200GenericLegacy
 {
  public:
  LX200Fs2();
