@@ -167,11 +167,17 @@ LX200Generic::LX200Generic()
    GuideNSTID     = 0;
    GuideWETID     = 0;
 
-   controller = new INDI::Controller(this);
-
+   controller = new INDI::Controller(this);   
    controller->setJoystickCallback(joystickHelper);
    controller->setButtonCallback(buttonHelper);
 
+   TelescopeCapability cap;
+
+   cap.canPark = true;
+   cap.canSync = true;
+   cap.canAbort = true;
+   SetTelescopeCapability(&cap);
+
    IDLog("Initializing from generic LX200 device...\n");   
 }
 
@@ -230,7 +236,7 @@ bool LX200Generic::initProperties()
 
     IUFillSwitch(&FocusMotionS[0], "IN", "Focus in", ISS_OFF);
     IUFillSwitch(&FocusMotionS[1], "OUT", "Focus out", ISS_OFF);
-    IUFillSwitchVector(&FocusMotionSP, FocusMotionS, 2, getDeviceName(), "FOCUS_MOTION", "Motion", FOCUS_TAB, IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    IUFillSwitchVector(&FocusMotionSP, FocusMotionS, 2, getDeviceName(), "FOCUS_MOTION", "Motion", FOCUS_TAB, IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
 
     IUFillNumber(&FocusTimerN[0], "TIMER", "Timer (ms)", "%g", 0, 10000., 1000., 0);
     IUFillNumberVector(&FocusTimerNP, FocusTimerN, 1, getDeviceName(), "FOCUS_TIMER", "Focus Timer", FOCUS_TAB, IP_RW, 0, IPS_IDLE);
@@ -249,7 +255,6 @@ bool LX200Generic::initProperties()
 
     controller->initProperties();
 
-
     TrackState=SCOPE_IDLE;
 
     initGuiderProperties(getDeviceName(), GUIDE_TAB);
@@ -257,6 +262,8 @@ bool LX200Generic::initProperties()
     /* Add debug/simulation/config controls so we may debug driver if necessary */
     addAuxControls();
 
+    setInterfaceDescriptor(getInterfaceDescriptor() | GUIDER_INTERFACE);
+
     return true;
 }
 
@@ -413,17 +420,8 @@ bool LX200Generic::ReadScopeStatus()
             SlewModeS[2].s = ISS_ON;
             IDSetSwitch(&SlewModeSP, NULL);
 
-            //  Nothing to do here
-            if(TrackState==SCOPE_PARKING)
-            {
-                TrackState=SCOPE_PARKED;
-                IDMessage(getDeviceName(),"Telescope is Parked.");
-            }
-            else
-            {
-                TrackState=SCOPE_TRACKING;
-                IDMessage(getDeviceName(),"Slew is complete. Tracking...");
-            }
+            TrackState=SCOPE_TRACKING;
+            IDMessage(getDeviceName(),"Slew is complete. Tracking...");
 
         }
     }
@@ -436,7 +434,6 @@ bool LX200Generic::ReadScopeStatus()
             IDSetSwitch(&ParkSP,NULL);
             IDMessage(getDeviceName(),"Telescope is Parked.");
         }
-
     }
 
     if ( getLX200RA(PortFD, &currentRA) < 0 || getLX200DEC(PortFD, &currentDEC) < 0)
@@ -603,84 +600,64 @@ bool LX200Generic::Park()
     return true;
 }
 
-bool LX200Generic::MoveNS(TelescopeMotionNS dir)
+bool LX200Generic::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
 {
-    static int last_move=-1;
+    int current_move = (dir == MOTION_NORTH) ? LX200_NORTH : LX200_SOUTH;
 
-     int current_move = -1;
-
-    current_move = IUFindOnSwitchIndex(&MovementNSSP);
-
-    // Previosuly active switch clicked again, so let's stop.
-    if (current_move == last_move && current_move != -1)
+    switch (command)
     {
-        if (isSimulation() == false)
-            HaltMovement(PortFD, (current_move == 0) ? LX200_NORTH : LX200_SOUTH);
+        case MOTION_START:
+        if (isSimulation() == false && MoveTo(PortFD, current_move) < 0)
+        {
+            DEBUG(INDI::Logger::DBG_ERROR, "Error setting N/S motion direction.");
+            return false;
+        }
+        else
+           DEBUGF(INDI::Logger::DBG_SESSION,"Moving toward %s.", (current_move == LX200_NORTH) ? "North" : "South");
+        break;
 
-        IUResetSwitch(&MovementNSSP);
-        MovementNSSP.s = IPS_IDLE;
-        IDSetSwitch(&MovementNSSP, "Movement toward %s halted.", (current_move == 0) ? "North" : "South");
-        last_move = -1;
-        return true;
+        case MOTION_STOP:
+        if (isSimulation() == false && HaltMovement(PortFD, current_move) < 0)
+        {
+            DEBUG(INDI::Logger::DBG_ERROR, "Error stopping N/S motion.");
+            return false;
+        }
+        else
+            DEBUGF(INDI::Logger::DBG_SESSION, "Movement toward %s halted.", (current_move == LX200_NORTH) ? "North" : "South");
+        break;
     }
 
-    last_move = current_move;
-
-    if (isDebug())
-        IDLog("Current Move: %d - Previous Move: %d\n", current_move, last_move);
-
-    // Correction for LX200 Driver: North 0 - South 3
-    current_move = (dir == MOTION_NORTH) ? LX200_NORTH : LX200_SOUTH;
-
-    if (isSimulation() == false && MoveTo(PortFD, current_move) < 0)
-    {
-        MovementNSSP.s = IPS_ALERT;
-        IDSetSwitch(&MovementNSSP, "Error setting N/S motion direction.");
-        return false;
-    }
-
-
-      MovementNSSP.s = IPS_BUSY;
-      IDSetSwitch(&MovementNSSP, "Moving toward %s.", (current_move == LX200_NORTH) ? "North" : "South");
-      return true;
+    return true;
 }
 
-bool LX200Generic::MoveWE(TelescopeMotionWE dir)
+bool LX200Generic::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
 {
-    static int last_move=-1;
 
-   int current_move = -1;
+    int current_move = (dir == MOTION_WEST) ? LX200_WEST : LX200_EAST;
 
-   current_move = IUFindOnSwitchIndex(&MovementWESP);
+    switch (command)
+    {
+        case MOTION_START:
+        if (isSimulation() == false && MoveTo(PortFD, current_move) < 0)
+        {
+            DEBUG(INDI::Logger::DBG_ERROR, "Error setting W/E motion direction.");
+            return false;
+        }
+        else
+           DEBUGF(INDI::Logger::DBG_SESSION,"Moving toward %s.", (current_move == LX200_WEST) ? "West" : "East");
+        break;
 
-  // Previosuly active switch clicked again, so let's stop.
-  if (current_move == last_move && current_move != -1)
-  {
-      if (isSimulation() == false)
-        HaltMovement(PortFD, (current_move == 0) ? LX200_WEST : LX200_EAST);
-      IUResetSwitch(&MovementWESP);
-      MovementWESP.s = IPS_IDLE;
-      IDSetSwitch(&MovementWESP, "Movement toward %s halted.", (current_move == 0) ? "West" : "East");
-      last_move = -1;
-      return true;
-  }
+        case MOTION_STOP:
+        if (isSimulation() == false && HaltMovement(PortFD, current_move) < 0)
+        {
+            DEBUG(INDI::Logger::DBG_ERROR, "Error stopping W/E motion.");
+            return false;
+        }
+        else
+            DEBUGF(INDI::Logger::DBG_SESSION, "Movement toward %s halted.", (current_move == LX200_WEST) ? "West" : "East");
+        break;
+    }
 
-  last_move = current_move;
-
-  if (isDebug())
-      IDLog("Current Move: %d - Previous Move: %d\n", current_move, last_move);
-
-  current_move = (dir == MOTION_WEST) ? LX200_WEST : LX200_EAST;
-
-  if (isSimulation() == false && MoveTo(PortFD, current_move) < 0)
-  {
-      MovementWESP.s = IPS_ALERT;
-      IDSetSwitch(&MovementWESP, "Error setting W/E motion direction.");
-      return false;
-  }
-
-    MovementWESP.s = IPS_BUSY;
-    IDSetSwitch(&MovementWESP, "Moving toward %s.", (current_move == LX200_WEST) ? "West" : "East");
     return true;
 }
 
@@ -728,6 +705,10 @@ bool LX200Generic::Abort()
      IDSetSwitch(&MovementNSSP, NULL);
      IDSetSwitch(&MovementWESP, NULL);
      IDSetNumber(&EqNP, NULL);
+     IUResetSwitch(&ParkSP);
+     ParkSP.s = IPS_IDLE;
+     IDSetSwitch(&ParkSP, NULL);
+
      IDMessage(getDeviceName(), "Slew aborted.");
      return true;
 }
@@ -1425,7 +1406,7 @@ bool LX200Generic::GuideNorth(float ms)
       {
           int dir = IUFindOnSwitchIndex(&MovementNSSP);
 
-          MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH);
+          MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
 
       }
 
@@ -1448,7 +1429,7 @@ bool LX200Generic::GuideNorth(float ms)
         }
 
         MovementNSS[0].s = ISS_ON;
-        MoveNS(MOTION_NORTH);
+        MoveNS(MOTION_NORTH, MOTION_START);
       }
 
       // Set slew to guiding
@@ -1477,7 +1458,7 @@ bool LX200Generic::GuideSouth(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementNSSP);
 
-        MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH);
+        MoveNS(dir == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
 
     }
 
@@ -1500,7 +1481,7 @@ bool LX200Generic::GuideSouth(float ms)
       }
 
       MovementNSS[1].s = ISS_ON;
-      MoveNS(MOTION_SOUTH);
+      MoveNS(MOTION_SOUTH, MOTION_START);
     }
 
     // Set slew to guiding
@@ -1531,7 +1512,7 @@ bool LX200Generic::GuideEast(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementWESP);
 
-        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST);
+        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
 
     }
 
@@ -1554,7 +1535,7 @@ bool LX200Generic::GuideEast(float ms)
       }
 
       MovementWES[1].s = ISS_ON;
-      MoveWE(MOTION_EAST);
+      MoveWE(MOTION_EAST, MOTION_START);
     }
 
     // Set slew to guiding
@@ -1585,7 +1566,7 @@ bool LX200Generic::GuideWest(float ms)
     {
         int dir = IUFindOnSwitchIndex(&MovementWESP);
 
-        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST);
+        MoveWE(dir == 0 ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
 
     }
 
@@ -1608,7 +1589,7 @@ bool LX200Generic::GuideWest(float ms)
       }
 
       MovementWES[0].s = ISS_ON;
-      MoveWE(MOTION_WEST);
+      MoveWE(MOTION_WEST, MOTION_START);
     }
 
     // Set slew to guiding
@@ -1653,7 +1634,7 @@ void LX200Generic::guideTimeout()
 
         if (guide_direction == LX200_NORTH || guide_direction == LX200_SOUTH)
         {
-            MoveNS(guide_direction == LX200_NORTH ? MOTION_NORTH : MOTION_SOUTH);
+            MoveNS(guide_direction == LX200_NORTH ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP);
 
             if (guide_direction == LX200_NORTH)
                 GuideNSNP.np[0].value = 0;
@@ -1668,7 +1649,7 @@ void LX200Generic::guideTimeout()
         }
         if (guide_direction == LX200_WEST || guide_direction == LX200_EAST)
         {
-            MoveWE(guide_direction == LX200_WEST ? MOTION_WEST : MOTION_EAST);
+            MoveWE(guide_direction == LX200_WEST ? MOTION_WEST : MOTION_EAST, MOTION_STOP);
             if (guide_direction == LX200_WEST)
                 GuideWENP.np[0].value = 0;
             else
@@ -1699,16 +1680,6 @@ void LX200Generic::guideTimeout()
     }
 }
 
-bool LX200Generic::canSync()
-{
-    return true;
-}
-
-bool LX200Generic::canPark()
-{
-    return true;
-}
-
 bool LX200Generic::ISSnoopDevice(XMLEle *root)
 {
 
@@ -1786,7 +1757,7 @@ void LX200Generic::processNSWE(double mag, double angle)
         {
             // Don't try to move if you're busy and moving in the same direction
             if (MovementNSSP.s != IPS_BUSY || MovementNSS[0].s != ISS_ON)
-                MoveNS(MOTION_NORTH);
+                MoveNS(MOTION_NORTH, MOTION_START);
 
             MovementNSSP.s = IPS_BUSY;
             MovementNSSP.sp[0].s = ISS_ON;
@@ -1798,7 +1769,7 @@ void LX200Generic::processNSWE(double mag, double angle)
         {
             // Don't try to move if you're busy and moving in the same direction
            if (MovementNSSP.s != IPS_BUSY  || MovementNSS[1].s != ISS_ON)
-            MoveNS(MOTION_SOUTH);
+            MoveNS(MOTION_SOUTH, MOTION_START);
 
             MovementNSSP.s = IPS_BUSY;
             MovementNSSP.sp[0].s = ISS_OFF;
@@ -1810,7 +1781,7 @@ void LX200Generic::processNSWE(double mag, double angle)
         {
             // Don't try to move if you're busy and moving in the same direction
            if (MovementWESP.s != IPS_BUSY  || MovementWES[1].s != ISS_ON)
-                MoveWE(MOTION_EAST);
+                MoveWE(MOTION_EAST, MOTION_START);
 
            MovementWESP.s = IPS_BUSY;
            MovementWESP.sp[0].s = ISS_OFF;
@@ -1824,7 +1795,7 @@ void LX200Generic::processNSWE(double mag, double angle)
 
             // Don't try to move if you're busy and moving in the same direction
            if (MovementWESP.s != IPS_BUSY  || MovementWES[0].s != ISS_ON)
-                MoveWE(MOTION_WEST);
+                MoveWE(MOTION_WEST, MOTION_START);
 
            MovementWESP.s = IPS_BUSY;
            MovementWESP.sp[0].s = ISS_ON;
@@ -1851,14 +1822,14 @@ void LX200Generic::processJoystick(const char * joystick_n, double mag, double a
 }
 
 
-void LX200Generic::joystickHelper(const char * joystick_n, double mag, double angle)
+void LX200Generic::joystickHelper(const char * joystick_n, double mag, double angle, void *context)
 {
-    telescope->processJoystick(joystick_n, mag, angle);
+    static_cast<LX200Generic *>(context)->processJoystick(joystick_n, mag, angle);
 
 }
 
-void LX200Generic::buttonHelper(const char * button_n, ISState state)
+void LX200Generic::buttonHelper(const char * button_n, ISState state, void *context)
 {
-    telescope->processButton(button_n, state);
+    static_cast<LX200Generic *>(context)->processButton(button_n, state);
 }
 
