@@ -52,13 +52,13 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
     void updateFocusTimer();
     void guideTimeout();
 
-    static void joystickHelper(const char * joystick_n, double mag, double angle);
-    static void buttonHelper(const char * button_n, ISState state);
+    static void joystickHelper(const char * joystick_n, double mag, double angle, void *context);
+    static void buttonHelper(const char * button_n, ISState state, void *context);
 
   protected:
 
-    virtual bool MoveNS(TelescopeMotionNS dir);
-    virtual bool MoveWE(TelescopeMotionWE dir);
+    virtual bool MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command);
+    virtual bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command);
     virtual bool Abort();
 
     virtual bool updateTime(ln_date * utc, double utc_offset);
@@ -74,8 +74,6 @@ class LX200Generic: public INDI::Telescope, public INDI::GuiderInterface
     virtual bool Goto(double,double);
     virtual bool Park();
     virtual bool Sync(double ra, double dec);
-    virtual bool canSync();
-    virtual bool canPark();
 
     virtual void debugTriggered(bool enable);
 
