@@ -91,6 +91,13 @@ SkywatcherAPIMount::SkywatcherAPIMount()
 #endif
     OldTrackingTarget[0] = 0;
     OldTrackingTarget[1] = 0;
+
+    TelescopeCapability cap;
+
+    cap.canPark = true;
+    cap.canSync = true;
+    cap.canAbort = true;
+    SetTelescopeCapability(&cap);
 }
 
 // destructor
@@ -113,11 +120,6 @@ bool  SkywatcherAPIMount::Abort()
     return true;
 }
 
-bool SkywatcherAPIMount::canSync()
-{
-    return true;
-}
-
 bool  SkywatcherAPIMount::Connect()
 {
     DEBUG(DBG_SCOPE, "SkywatcherAPIMount::Connect");
@@ -266,6 +268,9 @@ bool SkywatcherAPIMount::initProperties()
     // Add alignment properties
     InitProperties(this);
 
+    // Force the alignment system to always be on
+    getSwitch("ALIGNMENT_SUBSYSTEM_ACTIVE")->sp[0].s = ISS_ON;
+
     // Set up property variables
     IUFillNumber(&BasicMountInfo[MOTOR_CONTROL_FIRMWARE_VERSION], "MOTOR_CONTROL_FIRMWARE_VERSION",
                                                             "Motor control fimware version",
@@ -507,92 +512,50 @@ bool SkywatcherAPIMount::ISNewText (const char *dev, const char *name, char *tex
     return INDI::Telescope::ISNewText(dev, name, texts, names, n);
 }
 
-bool SkywatcherAPIMount::MoveNS(TelescopeMotionNS dir)
+bool SkywatcherAPIMount::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
 {
     DEBUG(DBG_SCOPE, "SkywatcherAPIMount::MoveNS");
-    switch (dir)
-    {
-        case MOTION_NORTH:
-            if (PreviousNSMotion != PREVIOUS_NS_MOTION_NORTH)
-            {
-                DEBUG(DBG_SCOPE, "Starting Slew North");
-                Slew(AXIS2, LOW_SPEED_MARGIN / 2);
-                PreviousNSMotion = PREVIOUS_NS_MOTION_NORTH;
-            }
-            else
-            {
-                DEBUG(DBG_SCOPE, "Stopping Slew North");
-                SlowStop(AXIS2);
-                PreviousNSMotion = PREVIOUS_NS_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementNSSP);
-                MovementNSSP.s = IPS_IDLE;
-                IDSetSwitch(&MovementNSSP, NULL);
-            }
-            break;
 
-        case MOTION_SOUTH:
-            if (PreviousNSMotion != PREVIOUS_NS_MOTION_SOUTH)
-            {
-                DEBUG(DBG_SCOPE, "Starting Slew South");
-                Slew(AXIS2, -LOW_SPEED_MARGIN / 2);
-                PreviousNSMotion = PREVIOUS_NS_MOTION_SOUTH;
-            }
-            else
-            {
-                DEBUG(DBG_SCOPE, "Stopping Slew South");
-                SlowStop(AXIS2);
-                PreviousNSMotion = PREVIOUS_NS_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementNSSP);
-                MovementNSSP.s = IPS_IDLE;
-                IDSetSwitch(&MovementNSSP, NULL);
-            }
-            break;
+    double speed = (dir == MOTION_NORTH) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
+    const char *dirStr = (dir == MOTION_NORTH) ? "North" : "South";
+
+    switch (command)
+    {
+        case MOTION_START:
+        DEBUGF(DBG_SCOPE, "Starting Slew %s", dirStr);
+        Slew(AXIS2, speed);
+        break;
+
+        case MOTION_STOP:
+        DEBUGF(DBG_SCOPE, "Stopping Slew %s", dirStr);
+        SlowStop(AXIS2);
+        break;
     }
-    return false;
+
+    return true;
 }
 
-bool SkywatcherAPIMount::MoveWE(TelescopeMotionWE dir)
+bool SkywatcherAPIMount::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
 {
     DEBUG(DBG_SCOPE, "SkywatcherAPIMount::MoveWE");
-    switch (dir)
-    {
-        case MOTION_WEST:
-            if (PreviousWEMotion != PREVIOUS_WE_MOTION_WEST)
-            {
-                DEBUG(DBG_SCOPE, "Starting Slew West");
-                Slew(AXIS1, LOW_SPEED_MARGIN / 2);
-                PreviousWEMotion = PREVIOUS_WE_MOTION_WEST;
-            }
-            else
-            {
-                DEBUG(DBG_SCOPE, "Stopping Slew West");
-                SlowStop(AXIS1);
-                PreviousWEMotion = PREVIOUS_WE_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementWESP);
-                MovementWESP.s = IPS_IDLE;
-                IDSetSwitch(&MovementWESP, NULL);
-            }
-            break;
 
-        case MOTION_EAST:
-            if (PreviousWEMotion != PREVIOUS_WE_MOTION_EAST)
-            {
-                DEBUG(DBG_SCOPE, "Starting Slew East");
-                Slew(AXIS1, -LOW_SPEED_MARGIN / 2);
-                PreviousWEMotion = PREVIOUS_WE_MOTION_EAST;
-            }
-            else
-            {
-                DEBUG(DBG_SCOPE, "Stopping Slew East");
-                SlowStop(AXIS1);
-                PreviousWEMotion = PREVIOUS_WE_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementWESP);
-                MovementWESP.s = IPS_IDLE;
-                IDSetSwitch(&MovementWESP, NULL);
-            }
-            break;
+    double speed = (dir == MOTION_WEST) ? (LOW_SPEED_MARGIN / 2) : -(LOW_SPEED_MARGIN / 2);
+    const char *dirStr = (dir == MOTION_WEST) ? "West" : "East";
+
+    switch (command)
+    {
+        case MOTION_START:
+        DEBUGF(DBG_SCOPE, "Starting Slew %s", dirStr);
+        Slew(AXIS1, speed);
+        break;
+
+        case MOTION_STOP:
+        DEBUGF(DBG_SCOPE, "Stopping Slew %s", dirStr);
+        SlowStop(AXIS1);
+        break;
     }
-    return false;
+
+    return true;
 }
 
 bool SkywatcherAPIMount::Park()
