@@ -14,13 +14,13 @@
 // We declare an auto pointer to ScopeSim.
 std::auto_ptr<ScopeSim> telescope_sim(0);
 
-#define	GOTO_RATE	2				/* slew rate, degrees/s */
+#define	GOTO_RATE	5				/* slew rate, degrees/s */
 #define	SLEW_RATE	0.5				/* slew rate, degrees/s */
 #define FINE_SLEW_RATE  0.1                             /* slew rate, degrees/s */
 #define SID_RATE	0.004178			/* sidereal rate, degrees/s */
 
-#define GOTO_LIMIT      5                               /* Move at GOTO_RATE until distance from target is GOTO_LIMIT degrees */
-#define SLEW_LIMIT      2                               /* Move at SLEW_LIMIT until distance from target is SLEW_LIMIT degrees */
+#define GOTO_LIMIT      5.5                             /* Move at GOTO_RATE until distance from target is GOTO_LIMIT degrees */
+#define SLEW_LIMIT      1                               /* Move at SLEW_LIMIT until distance from target is SLEW_LIMIT degrees */
 #define FINE_SLEW_LIMIT 0.5                             /* Move at FINE_SLEW_RATE until distance from target is FINE_SLEW_LIMIT degrees */
 
 #define	POLLMS		250				/* poll period, ms */
@@ -32,6 +32,9 @@ std::auto_ptr<ScopeSim> telescope_sim(0);
 #define GUIDE_WEST      0
 #define GUIDE_EAST      1
 
+#define MIN_AZ_FLIP     180
+#define MAX_AZ_FLIP     200
+
 void ISPoll(void *p);
 
 void ISInit()
@@ -95,8 +98,17 @@ ScopeSim::ScopeSim()
     currentDEC=90;
     Parked=false;
 
+    forceMeridianFlip = false;
+
     DBG_SCOPE = INDI::Logger::getInstance().addDebugLevel("Scope Verbose", "SCOPE");
 
+    TelescopeCapability cap;
+
+    cap.canPark = true;
+    cap.canSync = true;
+    cap.canAbort = true;    
+    SetTelescopeCapability(&cap);       
+
     /* initialize random seed: */
       srand ( time(NULL) );
 }
@@ -124,23 +136,23 @@ bool ScopeSim::initProperties()
     /* Enable client to manually add periodic error northward or southward for simulation purposes */
     IUFillSwitch(&PEErrNSS[MOTION_NORTH], "PE_N", "North", ISS_OFF);
     IUFillSwitch(&PEErrNSS[MOTION_SOUTH], "PE_S", "South", ISS_OFF);
-    IUFillSwitchVector(&PEErrNSSP, PEErrNSS, 2, getDeviceName(),"PE_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&PEErrNSSP, PEErrNSS, 2, getDeviceName(),"PE_NS", "PE N/S", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     /* Enable client to manually add periodic error westward or easthward for simulation purposes */
     IUFillSwitch(&PEErrWES[MOTION_WEST], "PE_W", "West", ISS_OFF);
     IUFillSwitch(&PEErrWES[MOTION_EAST], "PE_E", "East", ISS_OFF);
-    IUFillSwitchVector(&PEErrWESP, PEErrWES, 2, getDeviceName(),"PE_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&PEErrWESP, PEErrWES, 2, getDeviceName(),"PE_WE", "PE W/E", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     /* How fast do we guide compared to sidereal rate */
     IUFillNumber(&GuideRateN[RA_AXIS], "GUIDE_RATE_WE", "W/E Rate", "%g", 0, 1, 0.1, 0.3);
     IUFillNumber(&GuideRateN[DEC_AXIS], "GUIDE_RATE_NS", "N/S Rate", "%g", 0, 1, 0.1, 0.3);
     IUFillNumberVector(&GuideRateNP, GuideRateN, 2, getDeviceName(), "GUIDE_RATE", "Guiding Rate", MOTION_TAB, IP_RW, 0, IPS_IDLE);
 
-    // Let's simulate it to be an F/10 8" telescope
-    ScopeParametersN[0].value = 203;
-    ScopeParametersN[1].value = 2000;
-    ScopeParametersN[2].value = 203;
-    ScopeParametersN[3].value = 2000;
+    // Let's simulate it to be an F/7.5 120mm telescope
+    ScopeParametersN[0].value = 120;
+    ScopeParametersN[1].value = 900;
+    ScopeParametersN[2].value = 120;
+    ScopeParametersN[3].value = 900;
 
     TrackState=SCOPE_IDLE;
 
@@ -149,6 +161,8 @@ bool ScopeSim::initProperties()
     /* Add debug controls so we may debug driver if necessary */
     addDebugControl();
 
+    setInterfaceDescriptor(getInterfaceDescriptor() | GUIDER_INTERFACE);
+
     return true;
 }
 
@@ -232,7 +246,6 @@ bool ScopeSim::ReadScopeStatus()
     int nlocked, ns_guide_dir=-1, we_guide_dir=-1;
     char RA_DISP[64], DEC_DISP[64], RA_GUIDE[64], DEC_GUIDE[64], RA_PE[64], DEC_PE[64], RA_TARGET[64], DEC_TARGET[64];
 
-
     /* update elapsed time since last poll, don't presume exactly POLLMS */
     gettimeofday (&tv, NULL);
 
@@ -297,6 +310,24 @@ bool ScopeSim::ReadScopeStatus()
 
         dx = targetRA - currentRA;
 
+        // Always take the shortcut, don't go all around the globe
+        // If the difference between target and current is more than 12 hours, then we need to take the shortest path
+        if (dx > 12)
+            dx -= 24;
+        else if (dx < -12)
+            dx += 24;
+
+        // In meridian flip, alway force eastward motion (increasing RA) until target is reached.
+        if (forceMeridianFlip)
+        {
+            dx = fabs(dx);
+            if (dx == 0)
+            {
+                dx = 1;
+                da_ra = GOTO_LIMIT;
+            }
+        }
+
         if (fabs(dx)*15. <= da_ra)
         {
             currentRA = targetRA;
@@ -307,6 +338,7 @@ bool ScopeSim::ReadScopeStatus()
         else
             currentRA -= da_ra/15.;
 
+        currentRA = range24(currentRA);
 
         dy = targetDEC - currentDEC;
         if (fabs(dy) <= da_dec)
@@ -323,6 +355,8 @@ bool ScopeSim::ReadScopeStatus()
 
         if (nlocked == 2)
         {
+            forceMeridianFlip = false;
+
             if (TrackState == SCOPE_SLEWING)
             {
 
@@ -340,6 +374,9 @@ bool ScopeSim::ReadScopeStatus()
             else
             {
                 TrackState = SCOPE_PARKED;
+                IUResetSwitch(&ParkSP);
+                ParkSP.s=IPS_OK;
+                IDSetSwitch(&ParkSP,NULL);
                 EqNP.s = IPS_IDLE;
                 DEBUG(INDI::Logger::DBG_SESSION,"Telescope parked successfully.");
             }
@@ -467,13 +504,38 @@ bool ScopeSim::Goto(double r,double d)
     fs_sexa(RAStr, targetRA, 2, 3600);
     fs_sexa(DecStr, targetDEC, 2, 3600);
 
-    Parked=false;
-    TrackState = SCOPE_SLEWING;
+   ln_equ_posn lnradec;
+   lnradec.ra = (currentRA * 360) / 24.0;
+   lnradec.dec =currentDEC;
 
-    EqNP.s    = IPS_BUSY;
+   ln_get_hrz_from_equ(&lnradec, &lnobserver, ln_get_julian_from_sys(), &lnaltaz);
+   /* libnova measures azimuth from south towards west */
+   double current_az  =range360(lnaltaz.az + 180);
+   //double current_alt =lnaltaz.alt;
 
-    DEBUGF(INDI::Logger::DBG_SESSION,"Slewing to RA: %s - DEC: %s", RAStr, DecStr);
-    return true;
+   if (current_az > MIN_AZ_FLIP && current_az < MAX_AZ_FLIP)
+   {
+       lnradec.ra = (r*360) / 24.0;
+       lnradec.dec = d;
+
+       ln_get_hrz_from_equ(&lnradec, &lnobserver, ln_get_julian_from_sys(), &lnaltaz);
+
+       double target_az = range360(lnaltaz.az + 180);
+
+       //if (targetAz > currentAz && target_az > MIN_AZ_FLIP && target_az < MAX_AZ_FLIP)
+       if (target_az >= current_az && target_az > MIN_AZ_FLIP)
+       {
+           forceMeridianFlip = true;
+       }
+   }
+
+   Parked=false;
+   TrackState = SCOPE_SLEWING;
+
+   EqNP.s    = IPS_BUSY;
+
+   DEBUGF(INDI::Logger::DBG_SESSION,"Slewing to RA: %s - DEC: %s", RAStr, DecStr);
+   return true;
 }
 
 bool ScopeSim::Sync(double ra, double dec)
@@ -633,69 +695,14 @@ bool ScopeSim::Abort()
 }
 
 
-bool ScopeSim::MoveNS(TelescopeMotionNS dir)
+bool ScopeSim::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
 {
-    static int last_motion=-1;
-
-    switch (dir)
-    {
-      case MOTION_NORTH:
-        if (last_motion != MOTION_NORTH)
-            last_motion = MOTION_NORTH;
-        else
-        {
-            IUResetSwitch(&MovementNSSP);
-            MovementNSSP.s = IPS_IDLE;
-            IDSetSwitch(&MovementNSSP, NULL);
-        }
-        break;
-
-    case MOTION_SOUTH:
-      if (last_motion != MOTION_SOUTH)
-          last_motion = MOTION_SOUTH;
-      else
-      {
-          IUResetSwitch(&MovementNSSP);
-          MovementNSSP.s = IPS_IDLE;
-          IDSetSwitch(&MovementNSSP, NULL);
-      }
-      break;
-    }
-
     return true;
 }
 
-bool ScopeSim::MoveWE(TelescopeMotionWE dir)
+bool ScopeSim::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
 {
-    static int last_motion=-1;
-
-    switch (dir)
-    {
-      case MOTION_WEST:
-        if (last_motion != MOTION_WEST)
-            last_motion = MOTION_WEST;
-        else
-        {
-            IUResetSwitch(&MovementWESP);
-            MovementWESP.s = IPS_IDLE;
-            IDSetSwitch(&MovementWESP, NULL);
-        }
-        break;
-
-    case MOTION_EAST:
-      if (last_motion != MOTION_EAST)
-          last_motion = MOTION_EAST;
-      else
-      {
-          IUResetSwitch(&MovementWESP);
-          MovementWESP.s = IPS_IDLE;
-          IDSetSwitch(&MovementWESP, NULL);
-      }
-      break;
-    }
-
     return true;
-
 }
 
 bool ScopeSim::GuideNorth(float ms)
@@ -730,12 +737,32 @@ bool ScopeSim::GuideWest(float ms)
 
 }
 
-bool ScopeSim::canSync()
+double ScopeSim::range24(double r)
 {
-    return true;
+  double res = r;
+  while (res<0.0) res+=24.0;
+  while (res>24.0) res-=24.0;
+  return res;
 }
 
-bool ScopeSim::canPark()
+double ScopeSim::range360(double r)
 {
-    return true;
+  double res = r;
+  while (res<0.0) res+=360.0;
+  while (res>360.0) res-=360.0;
+  return res;
+}
+
+bool ScopeSim::updateLocation(double latitude, double longitude, double elevation)
+{
+  INDI_UNUSED(elevation);
+  // JM: INDI Longitude is 0 to 360 increasing EAST. libnova East is Positive, West is negative
+  lnobserver.lng =  longitude;
+
+  if (lnobserver.lng > 180)
+      lnobserver.lng -= 360;
+  lnobserver.lat =  latitude;
+
+  DEBUGF(INDI::Logger::DBG_SESSION,"Located updated: long = %g lat = %g", lnobserver.lng, lnobserver.lat);
+  return true;
 }
