@@ -20,7 +20,7 @@ std::auto_ptr<ScopeSim> telescope_sim(0);
 
 void ISInit()
 {
-   static int isInit =0;
+   static int isInit = 0;
 
    if (isInit == 1)
        return;
@@ -68,6 +68,8 @@ void ISSnoopDevice (XMLEle *root)
 const long ScopeSim::MICROSTEPS_PER_REVOLUTION = 1000000;
 const double ScopeSim::MICROSTEPS_PER_DEGREE = MICROSTEPS_PER_REVOLUTION / 360.0;
 const double ScopeSim::DEFAULT_SLEW_RATE = MICROSTEPS_PER_DEGREE * 2.0;
+const long ScopeSim::MAX_DEC = 90.0 * MICROSTEPS_PER_DEGREE;
+const long ScopeSim::MIN_DEC = -90.0 * MICROSTEPS_PER_DEGREE;
 
 // Private methods
 
@@ -128,6 +130,9 @@ const char * ScopeSim::getDefaultName()
 
 bool ScopeSim::Goto(double ra,double dec)
 {
+
+    DEBUGF(DBG_SIMULATOR, "Goto - Celestial reference frame target right ascension %lf(%lf) declination %lf", ra * 360.0 / 24.0, ra, dec);
+
     if (ISS_ON == IUFindSwitch(&CoordSP,"TRACK")->s)
     {
         char RAStr[32], DecStr[32];
@@ -135,6 +140,7 @@ bool ScopeSim::Goto(double ra,double dec)
         fs_sexa(DecStr, dec, 2, 3600);
         CurrentTrackingTarget.ra = ra;
         CurrentTrackingTarget.dec = dec;
+        DEBUG(DBG_SIMULATOR, "Goto - tracking requested");
     }
 
     // Call the alignment subsystem to translate the celestial reference frame coordinate
@@ -195,26 +201,52 @@ bool ScopeSim::Goto(double ra,double dec)
         }
     }
 
-    long AltitudeTargetMicrosteps = int(AltAz.alt * MICROSTEPS_PER_DEGREE);
-    long AzimuthTargetMicrosteps = int(AltAz.az * MICROSTEPS_PER_DEGREE);
-
-    // Do I need to take out any complete revolutions before I do this test?
-    if (AltitudeTargetMicrosteps > MICROSTEPS_PER_REVOLUTION / 2)
+    // My altitude encoder runs -90 to +90
+    if ((AltAz.alt > 90.0) || (AltAz.alt < -90.0))
     {
-        // Going the long way round - send it the other way
-        AltitudeTargetMicrosteps -= MICROSTEPS_PER_REVOLUTION;
+        DEBUG(DBG_SIMULATOR, "Goto - Altitude out of range");
+        // This should not happen
+        return false;
     }
 
-    if (AzimuthTargetMicrosteps > MICROSTEPS_PER_REVOLUTION / 2)
+    // My polar encoder runs 0 to +360
+    if ((AltAz.az > 360.0) || (AltAz.az < -360.0))
     {
-        // Going the long way round - send it the other way
-        AzimuthTargetMicrosteps -= MICROSTEPS_PER_REVOLUTION;
+        DEBUG(DBG_SIMULATOR, "Goto - Azimuth out of range");
+        // This should not happen
+        return false;
     }
 
-    GotoTargetMicrostepsDEC = AltitudeTargetMicrosteps;
-    AxisStatusDEC = SLEWING_TO;
-    GotoTargetMicrostepsRA = AzimuthTargetMicrosteps;
-    AxisStatusRA = SLEWING_TO;
+    if (AltAz.az < 0.0)
+    {
+        DEBUG(DBG_SIMULATOR, "Goto - Azimuth negative");
+        AltAz.az = 360.0 + AltAz.az;
+    }
+
+    DEBUGF(DBG_SIMULATOR, "Goto - Scope reference frame target altitude %lf azimuth %lf", AltAz.alt, AltAz.az);
+
+    GotoTargetMicrostepsDEC = int(AltAz.alt * MICROSTEPS_PER_DEGREE);
+    if (GotoTargetMicrostepsDEC == CurrentEncoderMicrostepsDEC)
+        AxisStatusDEC = STOPPED;
+    else
+    {
+        if (GotoTargetMicrostepsDEC > CurrentEncoderMicrostepsDEC)
+            AxisDirectionDEC = FORWARD;
+        else
+            AxisDirectionDEC = REVERSE;
+        AxisStatusDEC = SLEWING_TO;
+    }
+    GotoTargetMicrostepsRA = int(AltAz.az * MICROSTEPS_PER_DEGREE);
+    if (GotoTargetMicrostepsRA == CurrentEncoderMicrostepsRA)
+        AxisStatusRA = STOPPED;
+    else
+    {
+        if (GotoTargetMicrostepsRA > CurrentEncoderMicrostepsRA)
+            AxisDirectionRA = (GotoTargetMicrostepsRA - CurrentEncoderMicrostepsRA) < MICROSTEPS_PER_REVOLUTION / 2.0 ? FORWARD : REVERSE;
+        else
+            AxisDirectionRA = (CurrentEncoderMicrostepsRA - GotoTargetMicrostepsRA) < MICROSTEPS_PER_REVOLUTION / 2.0 ? REVERSE : FORWARD;
+        AxisStatusRA = SLEWING_TO;
+    }
 
     TrackState = SCOPE_SLEWING;
 
@@ -295,181 +327,145 @@ bool ScopeSim::ISNewText (const char *dev, const char *name, char *texts[], char
     return INDI::Telescope::ISNewText(dev, name, texts, names, n);
 }
 
-bool ScopeSim::MoveNS(TelescopeMotionNS dir)
+bool ScopeSim::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
 {
-    switch (dir)
-    {
-        case MOTION_NORTH:
-            if (PreviousNSMotion != PREVIOUS_NS_MOTION_NORTH)
-            {
-                AxisSlewRateDEC = DEFAULT_SLEW_RATE;
-                AxisDirectionDEC = FORWARD;
-                AxisStatusDEC = SLEWING;
-                PreviousNSMotion = PREVIOUS_NS_MOTION_NORTH;
-            }
-            else
-            {
-                AxisStatusDEC = STOPPED;
-                PreviousNSMotion = PREVIOUS_NS_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementNSSP);
-                MovementNSSP.s = IPS_IDLE;
-                IDSetSwitch(&MovementNSSP, NULL);
-            }
-            break;
+    AxisDirection axisDir  = (dir == MOTION_NORTH) ? FORWARD : REVERSE;
+    AxisStatus    axisStat = (command == MOTION_START) ? SLEWING : STOPPED;
 
-        case MOTION_SOUTH:
-            if (PreviousNSMotion != PREVIOUS_NS_MOTION_SOUTH)
-            {
-                AxisSlewRateDEC = DEFAULT_SLEW_RATE;
-                AxisDirectionDEC = REVERSE;
-                AxisStatusDEC = SLEWING;
-                PreviousNSMotion = PREVIOUS_NS_MOTION_SOUTH;
-            }
-            else
-            {
-                AxisStatusDEC = STOPPED;
-                PreviousNSMotion = PREVIOUS_NS_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementNSSP);
-                MovementNSSP.s = IPS_IDLE;
-                IDSetSwitch(&MovementNSSP, NULL);
-            }
-            break;
-    }
-    return false;
-}
-
-bool ScopeSim::MoveWE(TelescopeMotionWE dir)
-{
-    switch (dir)
-    {
-        case MOTION_WEST:
-            if (PreviousWEMotion != PREVIOUS_WE_MOTION_WEST)
-            {
-                AxisSlewRateRA = DEFAULT_SLEW_RATE;
-                AxisDirectionRA = FORWARD;
-                AxisStatusRA = SLEWING;
-                PreviousWEMotion = PREVIOUS_WE_MOTION_WEST;
-            }
-            else
-            {
-                AxisStatusRA = STOPPED;
-                PreviousWEMotion = PREVIOUS_WE_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementWESP);
-                MovementWESP.s = IPS_IDLE;
-                IDSetSwitch(&MovementWESP, NULL);
-            }
-            break;
-
-        case MOTION_EAST:
-            if (PreviousWEMotion != PREVIOUS_WE_MOTION_EAST)
-            {
-                AxisSlewRateRA = DEFAULT_SLEW_RATE;
-                AxisDirectionRA = REVERSE;
-                AxisStatusRA = SLEWING;
-                PreviousWEMotion = PREVIOUS_WE_MOTION_EAST;
-            }
-            else
-            {
-                AxisStatusRA = STOPPED;
-                PreviousWEMotion = PREVIOUS_WE_MOTION_UNKNOWN;
-                IUResetSwitch(&MovementWESP);
-                MovementWESP.s = IPS_IDLE;
-                IDSetSwitch(&MovementWESP, NULL);
-            }
-            break;
-    }
-    return false;
-}
-
-bool ScopeSim::ReadScopeStatus()
-{
-    struct ln_hrz_posn AltAz;
-    AltAz.alt = double(CurrentEncoderMicrostepsDEC) / MICROSTEPS_PER_DEGREE;
-    AltAz.az = double(CurrentEncoderMicrostepsRA) / MICROSTEPS_PER_DEGREE;
-    TelescopeDirectionVector TDV = TelescopeDirectionVectorFromAltitudeAzimuth(AltAz);
-
-    double RightAscension, Declination;
-    if (!TransformTelescopeToCelestial( TDV, RightAscension, Declination))
-    {
-        bool HavePosition = false;
-        ln_lnlat_posn Position;
-        if ((NULL != IUFindNumber(&LocationNP, "LAT")) && ( 0 != IUFindNumber(&LocationNP, "LAT")->value)
-            && (NULL != IUFindNumber(&LocationNP, "LONG")) && ( 0 != IUFindNumber(&LocationNP, "LONG")->value))
-        {
-            // I assume that being on the equator and exactly on the prime meridian is unlikely
-            Position.lat = IUFindNumber(&LocationNP, "LAT")->value;
-            Position.lng = IUFindNumber(&LocationNP, "LONG")->value;
-            HavePosition = true;
-        }
-        struct ln_equ_posn EquatorialCoordinates;
-        if (HavePosition)
-        {
-            TelescopeDirectionVector RotatedTDV(TDV);
-            switch (GetApproximateMountAlignment())
-            {
-                case ZENITH:
-                    break;
-
-                case NORTH_CELESTIAL_POLE:
-                    // Rotate the TDV coordinate system anticlockwise (positive) around the y axis by 90 minus
-                    // the (positive)observatory latitude. The vector itself is rotated clockwise
-                    RotatedTDV.RotateAroundY(90.0 - Position.lat);
-                    AltitudeAzimuthFromTelescopeDirectionVector(RotatedTDV, AltAz);
-                    break;
-
-                case SOUTH_CELESTIAL_POLE:
-                    // Rotate the TDV coordinate system clockwise (negative) around the y axis by 90 plus
-                    // the (negative)observatory latitude. The vector itself is rotated anticlockwise
-                    RotatedTDV.RotateAroundY(-90.0 - Position.lat);
-                    AltitudeAzimuthFromTelescopeDirectionVector(RotatedTDV, AltAz);
-                    break;
-            }
-            ln_get_equ_from_hrz(&AltAz, &Position, ln_get_julian_from_sys(), &EquatorialCoordinates);
-        }
-        else
-            // The best I can do is just do a direct conversion to RA/DEC
-            EquatorialCoordinatesFromTelescopeDirectionVector(TDV, EquatorialCoordinates);
-        // libnova works in decimal degrees
-        RightAscension = EquatorialCoordinates.ra * 24.0 / 360.0;
-        Declination = EquatorialCoordinates.dec;
-    }
-
-    NewRaDec(RightAscension, Declination);
+    AxisSlewRateDEC = DEFAULT_SLEW_RATE;
+    AxisDirectionDEC = axisDir;
+    AxisStatusDEC = axisStat;
 
     return true;
 }
 
-bool ScopeSim::Sync(double ra, double dec)
+bool ScopeSim::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
 {
-    struct ln_hrz_posn AltAz;
-    AltAz.alt = double(CurrentEncoderMicrostepsDEC) / MICROSTEPS_PER_DEGREE;
-    AltAz.az = double(CurrentEncoderMicrostepsRA) / MICROSTEPS_PER_DEGREE;
 
-    AlignmentDatabaseEntry NewEntry;
-    NewEntry.ObservationJulianDate = ln_get_julian_from_sys();
-    NewEntry.RightAscension = ra;
-    NewEntry.Declination = dec;
-    NewEntry.TelescopeDirection = TelescopeDirectionVectorFromAltitudeAzimuth(AltAz);
-    NewEntry.PrivateDataSize = 0;
+    AxisDirection axisDir  = (dir == MOTION_WEST) ? FORWARD : REVERSE;
+    AxisStatus    axisStat = (command == MOTION_START) ? SLEWING : STOPPED;
 
-    if (!CheckForDuplicateSyncPoint(NewEntry))
+    AxisSlewRateRA = DEFAULT_SLEW_RATE;
+    AxisDirectionRA = axisDir;
+    AxisStatusRA = axisStat;
+
+    return true;
+}
+
+    bool ScopeSim::ReadScopeStatus()
     {
+        struct ln_hrz_posn AltAz;
+        AltAz.alt = double(CurrentEncoderMicrostepsDEC) / MICROSTEPS_PER_DEGREE;
+        AltAz.az = double(CurrentEncoderMicrostepsRA) / MICROSTEPS_PER_DEGREE;
+        TelescopeDirectionVector TDV = TelescopeDirectionVectorFromAltitudeAzimuth(AltAz);
 
-        GetAlignmentDatabase().push_back(NewEntry);
+        double RightAscension, Declination;
+        if (!TransformTelescopeToCelestial( TDV, RightAscension, Declination))
+        {
+            if (TraceThisTick)
+                DEBUG(DBG_SIMULATOR, "ReadScopeStatus - TransformTelescopeToCelestial failed");
 
-        // Tell the client about size change
-        UpdateSize();
+            bool HavePosition = false;
+            ln_lnlat_posn Position;
+            if ((NULL != IUFindNumber(&LocationNP, "LAT")) && ( 0 != IUFindNumber(&LocationNP, "LAT")->value)
+                && (NULL != IUFindNumber(&LocationNP, "LONG")) && ( 0 != IUFindNumber(&LocationNP, "LONG")->value))
+            {
+                // I assume that being on the equator and exactly on the prime meridian is unlikely
+                Position.lat = IUFindNumber(&LocationNP, "LAT")->value;
+                Position.lng = IUFindNumber(&LocationNP, "LONG")->value;
+                HavePosition = true;
+            }
+            struct ln_equ_posn EquatorialCoordinates;
+            if (HavePosition)
+            {
+                if (TraceThisTick)
+                    DEBUG(DBG_SIMULATOR, "ReadScopeStatus - HavePosition true");
+                TelescopeDirectionVector RotatedTDV(TDV);
+                switch (GetApproximateMountAlignment())
+                {
+                    case ZENITH:
+                        if (TraceThisTick)
+                            DEBUG(DBG_SIMULATOR, "ReadScopeStatus - ApproximateMountAlignment ZENITH");
+                        break;
 
-        // Tell the math plugin to reinitialise
-        Initialise(this);
+                    case NORTH_CELESTIAL_POLE:
+                        if (TraceThisTick)
+                            DEBUG(DBG_SIMULATOR, "ReadScopeStatus - ApproximateMountAlignment NORTH_CELESTIAL_POLE");
+                        // Rotate the TDV coordinate system anticlockwise (positive) around the y axis by 90 minus
+                        // the (positive)observatory latitude. The vector itself is rotated clockwise
+                        RotatedTDV.RotateAroundY(90.0 - Position.lat);
+                        AltitudeAzimuthFromTelescopeDirectionVector(RotatedTDV, AltAz);
+                        break;
+
+                    case SOUTH_CELESTIAL_POLE:
+                        if (TraceThisTick)
+                            DEBUG(DBG_SIMULATOR, "ReadScopeStatus - ApproximateMountAlignment SOUTH_CELESTIAL_POLE");
+                        // Rotate the TDV coordinate system clockwise (negative) around the y axis by 90 plus
+                        // the (negative)observatory latitude. The vector itself is rotated anticlockwise
+                        RotatedTDV.RotateAroundY(-90.0 - Position.lat);
+                        AltitudeAzimuthFromTelescopeDirectionVector(RotatedTDV, AltAz);
+                        break;
+                }
+                ln_get_equ_from_hrz(&AltAz, &Position, ln_get_julian_from_sys(), &EquatorialCoordinates);
+            }
+            else
+            {
+                if (TraceThisTick)
+                    DEBUG(DBG_SIMULATOR, "ReadScopeStatus - HavePosition false");
+
+                // The best I can do is just do a direct conversion to RA/DEC
+                EquatorialCoordinatesFromTelescopeDirectionVector(TDV, EquatorialCoordinates);
+            }
+            // libnova works in decimal degrees
+            RightAscension = EquatorialCoordinates.ra * 24.0 / 360.0;
+            Declination = EquatorialCoordinates.dec;
+        }
+
+        if (TraceThisTick)
+            DEBUGF(DBG_SIMULATOR, "ReadScopeStatus - RA %lf hours DEC %lf degrees", RightAscension, Declination);
+
+        NewRaDec(RightAscension, Declination);
 
         return true;
     }
-    return false;
-}
+
+    bool ScopeSim::Sync(double ra, double dec)
+    {
+        struct ln_hrz_posn AltAz;
+        AltAz.alt = double(CurrentEncoderMicrostepsDEC) / MICROSTEPS_PER_DEGREE;
+        AltAz.az = double(CurrentEncoderMicrostepsRA) / MICROSTEPS_PER_DEGREE;
+
+        AlignmentDatabaseEntry NewEntry;
+        NewEntry.ObservationJulianDate = ln_get_julian_from_sys();
+        NewEntry.RightAscension = ra;
+        NewEntry.Declination = dec;
+        NewEntry.TelescopeDirection = TelescopeDirectionVectorFromAltitudeAzimuth(AltAz);
+        NewEntry.PrivateDataSize = 0;
+
+        if (!CheckForDuplicateSyncPoint(NewEntry))
+        {
+
+            GetAlignmentDatabase().push_back(NewEntry);
+
+            // Tell the client about size change
+            UpdateSize();
+
+            // Tell the math plugin to reinitialise
+            Initialise(this);
+
+            return true;
+        }
+        return false;
+    }
 
 void ScopeSim::TimerHit()
 {
+    TraceThisTickCount++;
+    if (60 == TraceThisTickCount)
+    {
+        TraceThisTick = true;
+        TraceThisTickCount = 0;
+    }
     // Simulate mount movement
 
     static struct timeval ltv; // previous system time
@@ -488,9 +484,9 @@ void ScopeSim::TimerHit()
 
     // RA axis
     long SlewSteps = dt * AxisSlewRateRA;
+    bool CompleteRevolution = SlewSteps >= MICROSTEPS_PER_REVOLUTION;
+    SlewSteps = SlewSteps % MICROSTEPS_PER_REVOLUTION; // Just in case ;-)
 
-    DEBUGF(DBG_SCOPE, "TimerHit - RA Current Encoder %ld SlewSteps %ld Direction %d Target %ld Status %d",
-                        CurrentEncoderMicrostepsRA, SlewSteps, AxisDirectionRA, GotoTargetMicrostepsRA, AxisStatusRA);
 
     switch(AxisStatusRA)
     {
@@ -500,8 +496,10 @@ void ScopeSim::TimerHit()
 
         case SLEWING:
         {
+            DEBUGF(DBG_SIMULATOR, "TimerHit Slewing - RA Current Encoder %ld SlewSteps %ld Direction %d Target %ld Status %d",
+                        CurrentEncoderMicrostepsRA, SlewSteps, AxisDirectionRA, GotoTargetMicrostepsRA, AxisStatusRA);
+
             // Update the encoder
-            SlewSteps = SlewSteps % MICROSTEPS_PER_REVOLUTION; // Just in case ;-)
             if (FORWARD == AxisDirectionRA)
                 CurrentEncoderMicrostepsRA += SlewSteps;
             else
@@ -510,56 +508,77 @@ void ScopeSim::TimerHit()
                 CurrentEncoderMicrostepsRA += MICROSTEPS_PER_REVOLUTION;
             else if (CurrentEncoderMicrostepsRA >= MICROSTEPS_PER_REVOLUTION)
                 CurrentEncoderMicrostepsRA -= MICROSTEPS_PER_REVOLUTION;
+
+            DEBUGF(DBG_SIMULATOR, "TimerHit Slewing - RA New Encoder %d New Status %d",  CurrentEncoderMicrostepsRA, AxisStatusRA);
             break;
         }
 
         case SLEWING_TO:
         {
-            // Calculate steps to target
-            int StepsToTarget;
+            DEBUGF(DBG_SIMULATOR, "TimerHit SlewingTo - RA Current Encoder %ld SlewSteps %ld Direction %d Target %ld Status %d",
+                        CurrentEncoderMicrostepsRA, SlewSteps, AxisDirectionRA, GotoTargetMicrostepsRA, AxisStatusRA);
+
+            long OldEncoder = CurrentEncoderMicrostepsRA;
+            // Update the encoder
             if (FORWARD == AxisDirectionRA)
-            {
-                if (CurrentEncoderMicrostepsRA <= GotoTargetMicrostepsRA)
-                    StepsToTarget = GotoTargetMicrostepsRA - CurrentEncoderMicrostepsRA;
-                else
-                    StepsToTarget = CurrentEncoderMicrostepsRA - GotoTargetMicrostepsRA;
-            }
+                CurrentEncoderMicrostepsRA += SlewSteps;
             else
+                CurrentEncoderMicrostepsRA -= SlewSteps;
+            if (CurrentEncoderMicrostepsRA < 0)
+                CurrentEncoderMicrostepsRA += MICROSTEPS_PER_REVOLUTION;
+            else if (CurrentEncoderMicrostepsRA >= MICROSTEPS_PER_REVOLUTION)
+                CurrentEncoderMicrostepsRA -= MICROSTEPS_PER_REVOLUTION;
+
+            if (CompleteRevolution)
             {
-                // Axis in reverse
-                if (CurrentEncoderMicrostepsRA >= GotoTargetMicrostepsRA)
-                    StepsToTarget = CurrentEncoderMicrostepsRA - GotoTargetMicrostepsRA;
-                else
-                    StepsToTarget = GotoTargetMicrostepsRA - CurrentEncoderMicrostepsRA;
-            }
-            if (StepsToTarget <= SlewSteps)
-            {
-                // Target was hit this tick
+                // Must have found the target
                 AxisStatusRA = STOPPED;
                 CurrentEncoderMicrostepsRA = GotoTargetMicrostepsRA;
             }
             else
             {
+                bool FoundTarget = false;
                 if (FORWARD == AxisDirectionRA)
-                    CurrentEncoderMicrostepsRA += SlewSteps;
+                {
+                    if (CurrentEncoderMicrostepsRA < OldEncoder)
+                    {
+                        // Two ranges to search
+                        if ((GotoTargetMicrostepsRA >= OldEncoder) && (GotoTargetMicrostepsRA <= MICROSTEPS_PER_REVOLUTION))
+                            FoundTarget = true;
+                        else if ((GotoTargetMicrostepsRA >= 0) && (GotoTargetMicrostepsRA <= CurrentEncoderMicrostepsRA))
+                            FoundTarget = true;
+                    }
+                    else if ((GotoTargetMicrostepsRA >= OldEncoder) && (GotoTargetMicrostepsRA <= CurrentEncoderMicrostepsRA))
+                        FoundTarget = true;
+                }
                 else
-                    CurrentEncoderMicrostepsRA -= SlewSteps;
-                if (CurrentEncoderMicrostepsRA < 0)
-                    CurrentEncoderMicrostepsRA += MICROSTEPS_PER_REVOLUTION;
-                else if (CurrentEncoderMicrostepsRA >= MICROSTEPS_PER_REVOLUTION)
-                    CurrentEncoderMicrostepsRA -= MICROSTEPS_PER_REVOLUTION;
+                {
+                    if (CurrentEncoderMicrostepsRA > OldEncoder)
+                    {
+                        // Two ranges to search
+                        if ((GotoTargetMicrostepsRA >= 0) && (GotoTargetMicrostepsRA <= OldEncoder))
+                            FoundTarget = true;
+                        else if ((GotoTargetMicrostepsRA >= CurrentEncoderMicrostepsRA) && (GotoTargetMicrostepsRA <= MICROSTEPS_PER_REVOLUTION))
+                            FoundTarget = true;
+                    }
+                    else if ((GotoTargetMicrostepsRA >= CurrentEncoderMicrostepsRA) && (GotoTargetMicrostepsRA <= OldEncoder))
+                        FoundTarget = true;
+                }
+                if (FoundTarget)
+                {
+                    AxisStatusRA = STOPPED;
+                    CurrentEncoderMicrostepsRA = GotoTargetMicrostepsRA;
+                }
             }
+            DEBUGF(DBG_SIMULATOR, "TimerHit SlewingTo - RA New Encoder %d New Status %d",  CurrentEncoderMicrostepsRA, AxisStatusRA);
+            break;
         }
     }
 
-    DEBUGF(DBG_SCOPE, "TimerHit - RA New Encoder %d New Status %d",  CurrentEncoderMicrostepsRA, AxisStatusRA);
 
     // DEC axis
     SlewSteps = dt * AxisSlewRateDEC;
 
-    DEBUGF(DBG_SCOPE, "TimerHit - DEC Current Encoder %ld SlewSteps %d Direction %ld Target %ld Status %d",
-                        CurrentEncoderMicrostepsDEC, SlewSteps, AxisDirectionDEC, GotoTargetMicrostepsDEC, AxisStatusDEC);
-
     switch(AxisStatusDEC)
     {
         case STOPPED:
@@ -568,21 +587,37 @@ void ScopeSim::TimerHit()
 
         case SLEWING:
         {
+            DEBUGF(DBG_SIMULATOR, "TimerHit Slewing - DEC Current Encoder %ld SlewSteps %d Direction %ld Target %ld Status %d",
+                        CurrentEncoderMicrostepsDEC, SlewSteps, AxisDirectionDEC, GotoTargetMicrostepsDEC, AxisStatusDEC);
+
             // Update the encoder
             SlewSteps = SlewSteps % MICROSTEPS_PER_REVOLUTION; // Just in case ;-)
             if (FORWARD == AxisDirectionDEC)
                 CurrentEncoderMicrostepsDEC += SlewSteps;
             else
                 CurrentEncoderMicrostepsDEC -= SlewSteps;
-            if (CurrentEncoderMicrostepsDEC < 0)
-                CurrentEncoderMicrostepsDEC += MICROSTEPS_PER_REVOLUTION;
-            else if (CurrentEncoderMicrostepsDEC >= MICROSTEPS_PER_REVOLUTION)
-                CurrentEncoderMicrostepsDEC -= MICROSTEPS_PER_REVOLUTION;
+            if (CurrentEncoderMicrostepsDEC > MAX_DEC)
+            {
+                CurrentEncoderMicrostepsDEC = MAX_DEC;
+                AxisStatusDEC = STOPPED; // Hit the buffers
+                DEBUG(DBG_SIMULATOR, "TimerHit - DEC axis hit the buffers at MAX_DEC");
+            }
+            else if(CurrentEncoderMicrostepsDEC < MIN_DEC)
+            {
+                CurrentEncoderMicrostepsDEC = MIN_DEC;
+                AxisStatusDEC = STOPPED; // Hit the buffers
+                DEBUG(DBG_SIMULATOR, "TimerHit - DEC axis hit the buffers at MIN_DEC");
+            }
+
+            DEBUGF(DBG_SIMULATOR, "TimerHit Slewing - DEC New Encoder %d New Status %d",  CurrentEncoderMicrostepsDEC, AxisStatusDEC);
             break;
         }
 
         case SLEWING_TO:
         {
+            DEBUGF(DBG_SIMULATOR, "TimerHit SlewingTo - DEC Current Encoder %ld SlewSteps %d Direction %ld Target %ld Status %d",
+                        CurrentEncoderMicrostepsDEC, SlewSteps, AxisDirectionDEC, GotoTargetMicrostepsDEC, AxisStatusDEC);
+
             // Calculate steps to target
             int StepsToTarget;
             if (FORWARD == AxisDirectionDEC)
@@ -617,11 +652,12 @@ void ScopeSim::TimerHit()
                 else if (CurrentEncoderMicrostepsDEC >= MICROSTEPS_PER_REVOLUTION)
                     CurrentEncoderMicrostepsDEC -= MICROSTEPS_PER_REVOLUTION;
             }
+
+            DEBUGF(DBG_SIMULATOR, "TimerHit SlewingTo - DEC New Encoder %d New Status %d",  CurrentEncoderMicrostepsDEC, AxisStatusDEC);
+            break;
         }
     }
 
-    DEBUGF(DBG_SCOPE, "TimerHit - DEC New Encoder %d New Status %d",  CurrentEncoderMicrostepsDEC, AxisStatusDEC);
-
     INDI::Telescope::TimerHit(); // This will call ReadScopeStatus
 
     // OK I have updated the celestial reference frame RA/DEC in ReadScopeStatus
@@ -634,6 +670,7 @@ void ScopeSim::TimerHit()
                 if (ISS_ON == IUFindSwitch(&CoordSP,"TRACK")->s)
                 {
                     // Goto has finished start tracking
+                    DEBUG(DBG_SIMULATOR, "TimerHit - Goto finished start tracking");
                     TrackState = SCOPE_TRACKING;
                     // Fall through to tracking case
                 }
@@ -684,52 +721,115 @@ void ScopeSim::TimerHit()
                     break;
                 }
             }
+
+            // My altitude encoder runs -90 to +90
+            if ((AltAz.alt > 90.0) || (AltAz.alt < -90.0))
+            {
+                DEBUG(DBG_SIMULATOR, "TimerHit tracking - Altitude out of range");
+                // This should not happen
+                return;
+            }
+
+            // My polar encoder runs 0 to +360
+            if ((AltAz.az > 360.0) || (AltAz.az < -360.0))
+            {
+                DEBUG(DBG_SIMULATOR, "TimerHit tracking - Azimuth out of range");
+                // This should not happen
+                return;
+            }
+
+            if (AltAz.az < 0.0)
+            {
+                DEBUG(DBG_SIMULATOR, "TimerHit tracking - Azimuth negative");
+                AltAz.az = 360.0 + AltAz.az;
+            }
+
             long AltitudeOffsetMicrosteps = int(AltAz.alt * MICROSTEPS_PER_DEGREE - CurrentEncoderMicrostepsDEC);
             long AzimuthOffsetMicrosteps = int(AltAz.az * MICROSTEPS_PER_DEGREE - CurrentEncoderMicrostepsRA);
 
-            if (AzimuthOffsetMicrosteps > MICROSTEPS_PER_REVOLUTION / 2)
-            {
-                // Going the long way round - send it the other way
-                AzimuthOffsetMicrosteps -= MICROSTEPS_PER_REVOLUTION;
-            }
+            DEBUGF(DBG_SIMULATOR, "TimerHit - Tracking AltitudeOffsetMicrosteps %d AzimuthOffsetMicrosteps %d",
+                    AltitudeOffsetMicrosteps, AzimuthOffsetMicrosteps);
+
             if (0 != AzimuthOffsetMicrosteps)
             {
                 // Calculate the slewing rates needed to reach that position
                 // at the correct time. This is simple as interval is one second
+                if (AzimuthOffsetMicrosteps > 0)
+                {
+                    if (AzimuthOffsetMicrosteps < MICROSTEPS_PER_REVOLUTION / 2.0)
+                    {
+                        // Forward
+                        AxisDirectionRA = FORWARD;
+                        AxisSlewRateRA = AzimuthOffsetMicrosteps;
+                    }
+                    else
+                    {
+                        // Reverse
+                        AxisDirectionRA = REVERSE;
+                        AxisSlewRateRA = MICROSTEPS_PER_REVOLUTION - AzimuthOffsetMicrosteps;
+                    }
+                }
+                else
+                {
+                    AzimuthOffsetMicrosteps = abs(AzimuthOffsetMicrosteps);
+                    if (AzimuthOffsetMicrosteps < MICROSTEPS_PER_REVOLUTION / 2.0)
+                    {
+                        // Forward
+                        AxisDirectionRA = REVERSE;
+                        AxisSlewRateRA = AzimuthOffsetMicrosteps;
+                    }
+                    else
+                    {
+                        // Reverse
+                        AxisDirectionRA = FORWARD;
+                        AxisSlewRateRA = MICROSTEPS_PER_REVOLUTION - AzimuthOffsetMicrosteps;
+                    }
+                }
                 AxisSlewRateRA = abs(AzimuthOffsetMicrosteps);
                 AxisDirectionRA = AzimuthOffsetMicrosteps > 0 ? FORWARD : REVERSE;  // !!!! BEWARE INERTIA FREE MOUNT
+                AxisStatusRA = SLEWING;
+                DEBUGF(DBG_SIMULATOR, "TimerHit - Tracking AxisSlewRateRA %lf AxisDirectionRA %d",
+                    AxisSlewRateRA, AxisDirectionRA);
             }
             else
             {
                 // Nothing to do - stop the axis
                 AxisStatusRA = STOPPED; // !!!! BEWARE INERTIA FREE MOUNT
+                DEBUG(DBG_SIMULATOR, "TimerHit - Tracking nothing to do stopping RA axis");
             }
 
-            if (AltitudeOffsetMicrosteps > MICROSTEPS_PER_REVOLUTION / 2)
-            {
-                // Going the long way round - send it the other way
-                AltitudeOffsetMicrosteps -= MICROSTEPS_PER_REVOLUTION;
-            }
             if (0 != AltitudeOffsetMicrosteps)
             {
                  // Calculate the slewing rates needed to reach that position
                 // at the correct time.
                 AxisSlewRateDEC = abs(AltitudeOffsetMicrosteps);
                 AxisDirectionDEC = AltitudeOffsetMicrosteps > 0 ? FORWARD : REVERSE;  // !!!! BEWARE INERTIA FREE MOUNT
+                AxisStatusDEC = SLEWING;
+                DEBUGF(DBG_SIMULATOR, "TimerHit - Tracking AxisSlewRateDEC %lf AxisDirectionDEC %d",
+                    AxisSlewRateDEC, AxisDirectionDEC);
             }
             else
             {
                 // Nothing to do - stop the axis
                 AxisStatusDEC = STOPPED;  // !!!! BEWARE INERTIA FREE MOUNT
+                DEBUG(DBG_SIMULATOR, "TimerHit - Tracking nothing to do stopping DEC axis");
             }
 
-            OldTrackingTargetMicrostepsDEC = AzimuthOffsetMicrosteps + CurrentEncoderMicrostepsRA;
-            OldTrackingTargetMicrostepsDEC = AltitudeOffsetMicrosteps + CurrentEncoderMicrostepsDEC;
             break;
         }
 
         default:
             break;
     }
+
+    TraceThisTick = false;
 }
 
+bool ScopeSim::updateLocation(double latitude, double longitude, double elevation)
+{
+    UpdateLocation(latitude, longitude, elevation);
+    return true;
+}
+
+
+
