@@ -31,6 +31,7 @@
 #include <locale.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <pthread.h>
 
 #include "lilxml.h"
 #include "base64.h"
@@ -39,6 +40,8 @@
 #include "indicom.h"
 #include "indidriver.h"
 
+pthread_mutex_t stdout_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 #define MAXRBUF 2048
 
 /* output a string expanding special characters into xml/html escape sequences */
@@ -89,6 +92,8 @@ char * escapeXML(const char *s, unsigned int MAX_BUF_SIZE)
 void
 IDDelete (const char *dev, const char *name, const char *fmt, ...)
 {
+    pthread_mutex_lock(&stdout_mutex);
+
 	xmlv1();
 	printf ("<delProperty\n  device='%s'\n", dev);
 	if (name)
@@ -104,6 +109,8 @@ IDDelete (const char *dev, const char *name, const char *fmt, ...)
 	}
 	printf ("/>\n");
 	fflush (stdout);
+
+    pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell indiserver we want to snoop on the given device/property.
@@ -112,6 +119,7 @@ IDDelete (const char *dev, const char *name, const char *fmt, ...)
 void
 IDSnoopDevice (const char *snooped_device_name, const char *snooped_property_name)
 {
+    pthread_mutex_lock(&stdout_mutex);
 	xmlv1();
 	if (snooped_property_name && snooped_property_name[0])
 	    printf ("<getProperties device='%s' name='%s'/>\n",
@@ -119,6 +127,7 @@ IDSnoopDevice (const char *snooped_device_name, const char *snooped_property_nam
 	else
 	    printf ("<getProperties device='%s'/>\n", snooped_device_name);
 	fflush (stdout);
+    pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell indiserver whether we want BLOBs from the given snooped device.
@@ -136,10 +145,12 @@ IDSnoopBLOBs (const char *snooped_device, BLOBHandling bh)
 	default: return;
 	}
 
+    pthread_mutex_lock(&stdout_mutex);
 	xmlv1();
 	printf ("<enableBLOB device='%s'>%s</enableBLOB>\n",
 						snooped_device, how);
 	fflush (stdout);
+    pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* "INDI" wrappers to the more generic eventloop facility. */
@@ -267,7 +278,7 @@ int IUUpdateNumber(INumberVectorProperty *nvp, double values[], char *names[], i
     
     if (values[i] < np->min || values[i] > np->max)
     {
-       nvp->s = IPS_IDLE;
+       nvp->s = IPS_ALERT;
        IDSetNumber(nvp, "Error: Invalid range for %s. Valid range is from %g to %g. Requested value is %g", np->name, np->min, np->max, values[i]);
        return -1;
     }
@@ -579,18 +590,24 @@ IUSnoopNumber (XMLEle *root, INumberVectorProperty *nvp)
 	(void) crackIPState (findXMLAttValu (root,"state"), &nvp->s);
 
 	/* match each INumber with a oneNumber */
+	setlocale(LC_NUMERIC,"C");
 	for (i = 0; i < nvp->nnp; i++) {
 	    for (ep = nextXMLEle(root,1); ep; ep = nextXMLEle(root,0)) {
-        if (!strcmp (tagXMLEle(ep)+3, "Number") &&
-			!strcmp (nvp->np[i].name, findXMLAttValu(ep, "name"))) {
-		    if (f_scansexa (pcdataXMLEle(ep), &nvp->np[i].value) < 0)
-			return (-1);	/* bad number format */
-		    break;
+	      if (!strcmp (tagXMLEle(ep)+3, "Number") &&
+		  !strcmp (nvp->np[i].name, findXMLAttValu(ep, "name"))) {
+		if (f_scansexa (pcdataXMLEle(ep), &nvp->np[i].value) < 0) {
+		  setlocale(LC_NUMERIC,"");
+		  return (-1);	/* bad number format */
 		}
+		break;
+	      }
+	    }
+	    if (!ep) {
+	      setlocale(LC_NUMERIC,"");
+	      return (-1);	/* element not found */
 	    }
-	    if (!ep)
-		return (-1);	/* element not found */
 	}
+	setlocale(LC_NUMERIC,"");
 
 	/* ok */
 	return (0);
@@ -821,6 +838,9 @@ dispatch (XMLEle *root, char msg[])
             if (crackDN (root, &dev, &name, msg) < 0)
                 return (-1);
 
+            if (!isPropDefined(name))
+                return -1;
+
             /* ensure property is not RO */
             for (i=0; i < nroCheck; i++)
             {
@@ -828,6 +848,8 @@ dispatch (XMLEle *root, char msg[])
               {
                if (roCheck[i].perm == IP_RO)
                  return -1;
+               else
+                   break;
               }
             }
 
@@ -879,6 +901,9 @@ dispatch (XMLEle *root, char msg[])
             if (crackDN (root, &dev, &name, msg) < 0)
                 return (-1);
 
+            if (!isPropDefined(name))
+                return -1;
+
             /* ensure property is not RO */
             for (i=0; i < nroCheck; i++)
             {
@@ -886,6 +911,8 @@ dispatch (XMLEle *root, char msg[])
               {
                if (roCheck[i].perm == IP_RO)
                  return -1;
+               else
+                   break;
               }
             }
 
@@ -939,6 +966,9 @@ dispatch (XMLEle *root, char msg[])
             if (crackDN (root, &dev, &name, msg) < 0)
                 return (-1);
 
+            if (!isPropDefined(name))
+                return -1;
+
             /* ensure property is not RO */
             for (i=0; i < nroCheck; i++)
             {
@@ -946,6 +976,8 @@ dispatch (XMLEle *root, char msg[])
               {
                if (roCheck[i].perm == IP_RO)
                  return -1;
+               else
+                   break;
               }
             }
 
@@ -994,6 +1026,9 @@ dispatch (XMLEle *root, char msg[])
             if (crackDN (root, &dev, &name, msg) < 0)
                 return (-1);
 
+            if (!isPropDefined(name))
+                return -1;
+
             /* seed for reallocs */
             if (!blobs) {
                 blobs = (char **) malloc (1);
@@ -1085,9 +1120,9 @@ dispatch (XMLEle *root, char msg[])
         return(1);
 }
 
-int IUReadConfig(const char *filename, const char *dev, char errmsg[])
+int IUReadConfig(const char *filename, const char *dev, const char *property, int silent, char errmsg[])
 {
-    char configFileName[MAXRBUF], configDefaultFileName[MAXRBUF];
+    char configFileName[MAXRBUF];
     char *rname, *rdev;
     XMLEle *root = NULL, *fproot = NULL;
     LilXML *lp = newLilXML();
@@ -1108,7 +1143,7 @@ int IUReadConfig(const char *filename, const char *dev, char errmsg[])
     fp = fopen(configFileName, "r");
     if (fp == NULL)
     {
-         snprintf(errmsg, MAXRBUF, "Unable to read config file. Error loading file %s: %s\n", configFileName, strerror(errno));
+         snprintf(errmsg, MAXRBUF, "Unable to read user config file. Error loading file %s: %s\n", configFileName, strerror(errno));
          return -1;
     }
 
@@ -1121,6 +1156,9 @@ int IUReadConfig(const char *filename, const char *dev, char errmsg[])
         return -1;
     }
 
+    if (nXMLEle(fproot) > 0 && silent != 1)
+        IDMessage(dev, "Loading device configuration...");
+
     for (root = nextXMLEle (fproot, 1); root != NULL; root = nextXMLEle (fproot, 0))
     {
 
@@ -1135,10 +1173,14 @@ int IUReadConfig(const char *filename, const char *dev, char errmsg[])
         if (strcmp(dev, rdev))
             continue;
 
-        dispatch(root, errmsg);
+        if ( (property && !strcmp(property, rname)) || property == NULL)
+            dispatch(root, errmsg);
 
     }
 
+    if (nXMLEle(fproot) > 0 && silent != 1)
+        IDMessage(dev, "Device configuration applied.");
+
     fclose(fp);
     delXMLEle(fproot);
     delXMLEle(root);
@@ -1201,6 +1243,8 @@ void
 IDMessage (const char *dev, const char *fmt, ...)
 {
 
+    pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         printf ("<message\n");
         if (dev)
@@ -1216,6 +1260,8 @@ IDMessage (const char *dev, const char *fmt, ...)
         }
         printf ("/>\n");
         fflush (stdout);
+
+     pthread_mutex_unlock(&stdout_mutex);
 }
 
 FILE * IUGetConfigFP(const char *filename, const char *dev, char errmsg[])
@@ -1257,17 +1303,25 @@ FILE * IUGetConfigFP(const char *filename, const char *dev, char errmsg[])
      return fp;
 }
 
-void IUSaveConfigTag(FILE *fp, int ctag)
+void IUSaveConfigTag(FILE *fp, int ctag, const char * dev, int silent)
 {
     if (!fp)
         return;
 
     /* Opening tag */
     if (ctag == 0)
+    {
         fprintf(fp, "<INDIDriver>\n");
+        if (silent != 1)
+            IDMessage(dev, "Saving device configuration...");
+    }
     /* Closing tag */
     else
+    {
        fprintf(fp, "</INDIDriver>\n");
+       if (silent != 1)
+           IDMessage(dev, "Device configuration saved.");
+    }
 }
 
 void IUSaveConfigNumber (FILE *fp, const INumberVectorProperty *nvp)
@@ -1362,6 +1416,8 @@ IDDefText (const ITextVectorProperty *tvp, const char *fmt, ...)
         int i;
         ROSC *SC;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<defTextVector\n");
@@ -1407,6 +1463,8 @@ IDDefText (const ITextVectorProperty *tvp, const char *fmt, ...)
 
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to create a new numeric vector property */
@@ -1416,6 +1474,8 @@ IDDefNumber (const INumberVectorProperty *n, const char *fmt, ...)
         int i;
         ROSC *SC;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<defNumberVector\n");
@@ -1472,6 +1532,8 @@ IDDefNumber (const INumberVectorProperty *n, const char *fmt, ...)
 
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to create a new switch vector property */
@@ -1482,6 +1544,8 @@ IDDefSwitch (const ISwitchVectorProperty *s, const char *fmt, ...)
         int i;
         ROSC *SC;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<defSwitchVector\n");
@@ -1528,6 +1592,8 @@ IDDefSwitch (const ISwitchVectorProperty *s, const char *fmt, ...)
 
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to create a new lights vector property */
@@ -1536,6 +1602,8 @@ IDDefLight (const ILightVectorProperty *lvp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         printf ("<defLightVector\n");
         printf ("  device='%s'\n", lvp->device);
@@ -1565,6 +1633,8 @@ IDDefLight (const ILightVectorProperty *lvp, const char *fmt, ...)
 
         printf ("</defLightVector>\n");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to create a new BLOB vector property */
@@ -1574,6 +1644,8 @@ IDDefBLOB (const IBLOBVectorProperty *b, const char *fmt, ...)
   int i;
   ROSC *SC;
 
+  pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<defBLOBVector\n");
@@ -1618,6 +1690,8 @@ IDDefBLOB (const IBLOBVectorProperty *b, const char *fmt, ...)
 
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update an existing text vector property */
@@ -1626,6 +1700,8 @@ IDSetText (const ITextVectorProperty *tvp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<setTextVector\n");
@@ -1654,6 +1730,8 @@ IDSetText (const ITextVectorProperty *tvp, const char *fmt, ...)
         printf ("</setTextVector>\n");
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update an existing numeric vector property */
@@ -1662,6 +1740,8 @@ IDSetNumber (const INumberVectorProperty *nvp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<setNumberVector\n");
@@ -1690,6 +1770,8 @@ IDSetNumber (const INumberVectorProperty *nvp, const char *fmt, ...)
         printf ("</setNumberVector>\n");
         setlocale(LC_NUMERIC,"");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update an existing switch vector property */
@@ -1698,6 +1780,8 @@ IDSetSwitch (const ISwitchVectorProperty *svp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<setSwitchVector\n");
@@ -1726,6 +1810,8 @@ IDSetSwitch (const ISwitchVectorProperty *svp, const char *fmt, ...)
         printf ("</setSwitchVector>\n");
         setlocale(LC_NUMERIC,"");
        fflush (stdout);
+
+       pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update an existing lights vector property */
@@ -1734,6 +1820,8 @@ IDSetLight (const ILightVectorProperty *lvp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         printf ("<setLightVector\n");
         printf ("  device='%s'\n", lvp->device);
@@ -1759,6 +1847,8 @@ IDSetLight (const ILightVectorProperty *lvp, const char *fmt, ...)
 
         printf ("</setLightVector>\n");
         fflush (stdout);
+
+        pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update an existing BLOB vector property */
@@ -1767,6 +1857,8 @@ IDSetBLOB (const IBLOBVectorProperty *bvp, const char *fmt, ...)
 {
         int i;
 
+        pthread_mutex_lock(&stdout_mutex);
+
         xmlv1();
         setlocale(LC_NUMERIC,"C");
         printf ("<setBLOBVector\n");
@@ -1807,6 +1899,8 @@ IDSetBLOB (const IBLOBVectorProperty *bvp, const char *fmt, ...)
   printf ("</setBLOBVector>\n");
   setlocale(LC_NUMERIC,"");
   fflush (stdout);
+
+  pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* tell client to update min/max elements of an existing number vector property */
@@ -1814,6 +1908,7 @@ void IUUpdateMinMax(const INumberVectorProperty *nvp)
 {
   int i;
 
+  pthread_mutex_lock(&stdout_mutex);
   xmlv1();
   setlocale(LC_NUMERIC,"C");
   printf ("<setNumberVector\n");
@@ -1838,6 +1933,7 @@ void IUUpdateMinMax(const INumberVectorProperty *nvp)
   printf ("</setNumberVector>\n");
   setlocale(LC_NUMERIC,"");
   fflush (stdout);
+  pthread_mutex_unlock(&stdout_mutex);
 }
 
 /* Return 1 is property is already cached, 0 otherwise */
