@@ -217,7 +217,7 @@ void INDI::BaseClient::setDriverConnection(bool status, const char *deviceName)
 INDI::BaseDevice * INDI::BaseClient::getDevice(const char * deviceName)
 {
     vector<INDI::BaseDevice *>::const_iterator devi;
-    for ( devi = cDevices.begin(); devi != cDevices.end(); devi++)
+    for ( devi = cDevices.begin(); devi != cDevices.end(); ++devi)
         if (!strcmp(deviceName, (*devi)->getDeviceName()))
             return (*devi);
 
@@ -679,7 +679,7 @@ void INDI::BaseClient::sendOneBlob( const char *blobName, unsigned int blobSize,
 {
     fprintf(svrwfp, "  <oneBLOB\n");
     fprintf(svrwfp, "    name='%s'\n", blobName);
-    fprintf(svrwfp, "    size='%d'\n", blobSize);
+    fprintf(svrwfp, "    size='%ud'\n", blobSize);
     fprintf(svrwfp, "    format='%s'>\n", blobFormat);
 
     for (unsigned i = 0; i < blobSize; i += 72)
