@@ -52,11 +52,8 @@ INDI::BaseDevice::BaseDevice()
 INDI::BaseDevice::~BaseDevice()
 {
     delLilXML (lp);
-    while(!pAll.empty())
-    {
-      delete pAll.back();
-      pAll.pop_back();
-    }
+    while(!pAll.empty()) { delete pAll.back(), pAll.pop_back(); }
+    messageLog.clear();
 
     delete[] deviceID;
 }
@@ -106,6 +103,129 @@ IBLOBVectorProperty * INDI::BaseDevice::getBLOB(const char *name)
   return bvp;
 }
 
+IPState INDI::BaseDevice::getPropertyState(const char *name)
+{
+    IPState state = IPS_IDLE;
+    INDI_TYPE pType;
+    void *pPtr;
+
+    INumberVectorProperty *nvp;
+    ITextVectorProperty *tvp;
+    ISwitchVectorProperty *svp;
+    ILightVectorProperty *lvp;
+    IBLOBVectorProperty *bvp;
+
+    std::vector<INDI::Property *>::iterator orderi = pAll.begin();
+
+    for (; orderi != pAll.end(); ++orderi)
+    {
+        pType       = (*orderi)->getType();
+        pPtr        = (*orderi)->getProperty();
+
+        switch (pType)
+        {
+        case INDI_NUMBER:
+            nvp = static_cast<INumberVectorProperty *>(pPtr);
+            if (nvp == NULL)
+                continue;
+            if (!strcmp(name, nvp->name))
+                return nvp->s;
+            break;
+        case INDI_SWITCH:
+            svp = static_cast<ISwitchVectorProperty *>(pPtr);
+            if (svp == NULL)
+                continue;
+            if (!strcmp(name, svp->name))
+                return svp->s;
+            break;
+        case INDI_TEXT:
+            tvp = static_cast<ITextVectorProperty *>(pPtr);
+            if (tvp == NULL)
+                continue;
+            if (!strcmp(name, tvp->name))
+                return tvp->s;
+            break;
+        case INDI_LIGHT:
+            lvp = static_cast<ILightVectorProperty *>(pPtr);
+            if (lvp == NULL)
+                continue;
+            if (!strcmp(name, lvp->name))
+                return lvp->s;
+            break;
+        case INDI_BLOB:
+            bvp = static_cast<IBLOBVectorProperty *>(pPtr);
+            if (bvp == NULL)
+                continue;
+            if (!strcmp(name, bvp->name))
+                return bvp->s;
+            break;
+         default:
+            break;
+        }
+    }
+
+    return state;
+
+}
+
+IPerm INDI::BaseDevice::getPropertyPermission(const char *name)
+{
+    IPerm perm = IP_RO;
+
+    INDI_TYPE pType;
+    void *pPtr;
+
+    INumberVectorProperty *nvp;
+    ITextVectorProperty *tvp;
+    ISwitchVectorProperty *svp;
+    ILightVectorProperty *lvp;
+    IBLOBVectorProperty *bvp;
+
+    std::vector<INDI::Property *>::iterator orderi = pAll.begin();
+
+    for (; orderi != pAll.end(); ++orderi)
+    {
+        pType       = (*orderi)->getType();
+        pPtr        = (*orderi)->getProperty();
+
+        switch (pType)
+        {
+        case INDI_NUMBER:
+            nvp = static_cast<INumberVectorProperty *>(pPtr);
+            if (nvp == NULL)
+                continue;
+            if (!strcmp(name, nvp->name))
+                return nvp->p;
+            break;
+        case INDI_SWITCH:
+            svp = static_cast<ISwitchVectorProperty *>(pPtr);
+            if (svp == NULL)
+                continue;
+            if (!strcmp(name, svp->name))
+                return svp->p;
+            break;
+        case INDI_TEXT:
+            tvp = static_cast<ITextVectorProperty *>(pPtr);
+            if (tvp == NULL)
+                continue;
+            if (!strcmp(name, tvp->name))
+                return tvp->p;
+            break;
+        case INDI_BLOB:
+            bvp = static_cast<IBLOBVectorProperty *>(pPtr);
+            if (bvp == NULL)
+                continue;
+            if (!strcmp(name, bvp->name))
+                return bvp->p;
+            break;
+         default:
+            break;
+        }
+    }
+
+    return perm;
+
+}
 
 void * INDI::BaseDevice::getRawProperty(const char *name, INDI_TYPE type)
 {
@@ -356,7 +476,11 @@ bool INDI::BaseDevice::buildSkeleton(const char *filename)
           filename = slash + 1;
         const char *indiprefix = getenv("INDIPREFIX");
         if (indiprefix) {
+#ifdef OSX_EMBEDED_MODE
+          snprintf(pathname, MAXRBUF-1, "%s/Contents/Resources/%s", indiprefix, filename);
+#else
           snprintf(pathname, MAXRBUF-1, "%s/share/indi/%s", indiprefix, filename);
+#endif
         } else {
           snprintf(pathname, MAXRBUF-1, "%s/%s", DATA_INSTALL_DIR, filename);
         }
@@ -1076,28 +1200,30 @@ void INDI::BaseDevice::doMessage (XMLEle *msg)
     XMLAtt *message;
     XMLAtt *time_stamp;
 
-    // FIXME: delete the buffer in the destructor!
-    char * msgBuffer = new char[MAXRBUF];
+    char msgBuffer[MAXRBUF];
 
     /* prefix our timestamp if not with msg */
     time_stamp = findXMLAtt (msg, "timestamp");
 
     /* finally! the msg */
     message = findXMLAtt(msg, "message");
-        if (!message) return;
+    if (!message)
+        return;
 
     if (time_stamp)
         snprintf(msgBuffer, MAXRBUF, "%s: %s ", valuXMLAtt(time_stamp), valuXMLAtt(message));
     else
         snprintf(msgBuffer, MAXRBUF, "%s: %s ", timestamp(), valuXMLAtt(message));
 
+   string finalMsg = msgBuffer;
+
     // Prepend to the log
-   addMessage(msgBuffer);
+   addMessage(finalMsg);
 
 }
 
 
-void INDI::BaseDevice::addMessage(const char *msg)
+void INDI::BaseDevice::addMessage(string msg)
 {
     messageLog.push_back(msg);
 
@@ -1105,7 +1231,7 @@ void INDI::BaseDevice::addMessage(const char *msg)
         mediator->newMessage(this, messageLog.size()-1);
 }
 
-const char * INDI::BaseDevice::messageQueue(int index)
+string INDI::BaseDevice::messageQueue(int index)
 {
     if (index >= messageLog.size())
         return NULL;
@@ -1114,7 +1240,7 @@ const char * INDI::BaseDevice::messageQueue(int index)
 
 }
 
-const char * INDI::BaseDevice::lastMessage()
+string INDI::BaseDevice::lastMessage()
 {
     return messageLog.back();
 }
@@ -1217,7 +1343,7 @@ const char *INDI::BaseDevice::getDriverName()
     if (driverInfo == NULL)
         return NULL;
 
-    IText *driverName = IUFindText(driverInfo, "NAME");
+    IText *driverName = IUFindText(driverInfo, "DRIVER_NAME");
     if (driverName)
         return driverName->text;
 
@@ -1231,10 +1357,38 @@ const char *INDI::BaseDevice::getDriverExec()
     if (driverInfo == NULL)
         return NULL;
 
-    IText *driverExec = IUFindText(driverInfo, "EXEC");
+    IText *driverExec = IUFindText(driverInfo, "DRIVER_EXEC");
     if (driverExec)
         return driverExec->text;
 
     return NULL;
 }
 
+const char *INDI::BaseDevice::getDriverVersion()
+{
+    ITextVectorProperty *driverInfo = getText("DRIVER_INFO");
+
+    if (driverInfo == NULL)
+        return NULL;
+
+    IText *driverVersion = IUFindText(driverInfo, "DRIVER_VERSION");
+    if (driverVersion)
+        return driverVersion->text;
+
+    return NULL;
+}
+
+unsigned int INDI::BaseDevice::getDriverInterface()
+{
+    ITextVectorProperty *driverInfo = getText("DRIVER_INFO");
+
+    if (driverInfo == NULL)
+        return 0;
+
+    IText *driverInterface = IUFindText(driverInfo, "DRIVER_INTERFACE");
+    if (driverInterface)
+        return atoi(driverInterface->text);
+
+    return 0;
+}
+
