@@ -67,19 +67,21 @@ INDI::DefaultDevice::~DefaultDevice()
 {
 }
 
-bool INDI::DefaultDevice::loadConfig(bool silent)
+bool INDI::DefaultDevice::loadConfig(bool silent, const char *property)
 {
     char errmsg[MAXRBUF];
     bool pResult = false;
 
-    pResult = IUReadConfig(NULL, deviceID, errmsg) == 0 ? true : false;
+    pResult = IUReadConfig(NULL, deviceID, property, silent ? 1 : 0, errmsg) == 0 ? true : false;
 
    if (silent == false)
    {
     if (pResult)
+    {
             DEBUG(INDI::Logger::DBG_DEBUG, "Configuration successfully loaded.");
+    }
         else
-            DEBUGF(INDI::Logger::DBG_ERROR, "Error loading configuration. %s", errmsg);
+            DEBUGF(INDI::Logger::DBG_ERROR, "Error loading user configuration. %s. To save user configuration, click Save under the Configuration property in the Options tab. ", errmsg);
    }
 
    IUSaveDefaultConfig(NULL, NULL, deviceID);
@@ -132,7 +134,7 @@ bool INDI::DefaultDevice::saveConfigItems(FILE *fp)
 	return true;
 }
 
-bool INDI::DefaultDevice::saveConfig()
+bool INDI::DefaultDevice::saveConfig(bool silent)
 {
     //std::vector<orderPtr>::iterator orderi;
     char errmsg[MAXRBUF];
@@ -143,15 +145,16 @@ bool INDI::DefaultDevice::saveConfig()
 
     if (fp == NULL)
     {
-        DEBUGF(INDI::Logger::DBG_ERROR, "Error saving configuration. %s", errmsg);
+        if (silent == false)
+            DEBUGF(INDI::Logger::DBG_ERROR, "Error saving configuration. %s", errmsg);
         return false;
     }
 
-    IUSaveConfigTag(fp, 0);
+    IUSaveConfigTag(fp, 0, getDeviceName(), silent ? 1 : 0);
 
 	saveConfigItems(fp);
 
-    IUSaveConfigTag(fp, 1);
+    IUSaveConfigTag(fp, 1, getDeviceName(), silent ? 1 : 0);
 
     fclose(fp);
 
@@ -176,7 +179,7 @@ bool INDI::DefaultDevice::loadDefaultConfig()
 
     DEBUGF(INDI::Logger::DBG_DEBUG, "Requesting to load default config with: %s", configDefaultFileName);
 
-    pResult = IUReadConfig(configDefaultFileName, deviceID, errmsg) == 0 ? true : false;
+    pResult = IUReadConfig(configDefaultFileName, deviceID, NULL, 0, errmsg) == 0 ? true : false;
 
     if (pResult)
         DEBUG(INDI::Logger::DBG_SESSION, "Default configuration loaded.");
@@ -380,7 +383,7 @@ void INDI::DefaultDevice::setDebug(bool enable)
     pDebug = enable;
 
     // Inform logger
-    if (Logger::updateProperties(enable, this) == false)
+    if (Logger::updateProperties(enable) == false)
       DEBUG(Logger::DBG_WARNING,"setLogDebug: Logger error");
 
     debugTriggered(enable);
@@ -597,22 +600,38 @@ bool INDI::DefaultDevice::updateProperties()
     return true;
 }
 
+unsigned int INDI::DefaultDevice::getInterfaceDescriptor() const
+{
+    return interfaceDescriptor;
+}
+
+void INDI::DefaultDevice::setInterfaceDescriptor(unsigned int value)
+{
+    char interfaceStr[16];
+    interfaceDescriptor = value;
+    snprintf(interfaceStr, 16, "%d", interfaceDescriptor);
+    IUSaveText(&DriverInfoT[3], interfaceStr);
+}
+
 
 bool INDI::DefaultDevice::initProperties()
 {
     char versionStr[16];
+    char interfaceStr[16];
 
     snprintf(versionStr, 16, "%d.%d", majorVersion, minorVersion);
+    snprintf(interfaceStr, 16, "%d", interfaceDescriptor);
 
     IUFillSwitch(&ConnectionS[0],"CONNECT","Connect",ISS_OFF);
     IUFillSwitch(&ConnectionS[1],"DISCONNECT","Disconnect",ISS_ON);
     IUFillSwitchVector(&ConnectionSP,ConnectionS,2,getDeviceName(),"CONNECTION","Connection","Main Control",IP_RW,ISR_1OFMANY,60,IPS_IDLE);
     registerProperty(&ConnectionSP, INDI_SWITCH);
 
-    IUFillText(&DriverInfoT[0],"NAME","Name",getDefaultName());
-    IUFillText(&DriverInfoT[1],"EXEC","Exec",getDriverName());
-    IUFillText(&DriverInfoT[2],"VERSION","Version",versionStr);
-    IUFillTextVector(&DriverInfoTP,DriverInfoT,3,getDeviceName(),"DRIVER_INFO","Driver Info",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
+    IUFillText(&DriverInfoT[0],"DRIVER_NAME","Name",getDefaultName());
+    IUFillText(&DriverInfoT[1],"DRIVER_EXEC","Exec",getDriverName());
+    IUFillText(&DriverInfoT[2],"DRIVER_VERSION","Version",versionStr);
+    IUFillText(&DriverInfoT[3],"DRIVER_INTERFACE","Interface", interfaceStr);
+    IUFillTextVector(&DriverInfoTP,DriverInfoT,4,getDeviceName(),"DRIVER_INFO","Driver Info",OPTIONS_TAB,IP_RO,60,IPS_IDLE);
     registerProperty(&DriverInfoTP, INDI_TEXT);
 
     IUFillSwitch(&DebugS[0], "ENABLE", "Enable", ISS_OFF);
@@ -626,7 +645,9 @@ bool INDI::DefaultDevice::initProperties()
     IUFillSwitch(&ConfigProcessS[0], "CONFIG_LOAD", "Load", ISS_OFF);
     IUFillSwitch(&ConfigProcessS[1], "CONFIG_SAVE", "Save", ISS_OFF);
     IUFillSwitch(&ConfigProcessS[2], "CONFIG_DEFAULT", "Default", ISS_OFF);
-    IUFillSwitchVector(&ConfigProcessSP, ConfigProcessS, NARRAY(ConfigProcessS), getDeviceName(), "CONFIG_PROCESS", "Configuration", "Options", IP_RW, ISR_1OFMANY, 0, IPS_IDLE);
+    IUFillSwitchVector(&ConfigProcessSP, ConfigProcessS, NARRAY(ConfigProcessS), getDeviceName(), "CONFIG_PROCESS", "Configuration", "Options", IP_RW, ISR_ATMOST1, 0, IPS_IDLE);
+
+    INDI::Logger::initProperties(this);
 
     // Ready the logger
     std::string logFile;
@@ -642,9 +663,13 @@ bool INDI::DefaultDevice::deleteProperty(const char *propertyName)
 {
     char errmsg[MAXRBUF];
 
-    removeProperty(propertyName, errmsg);
-    IDDelete(getDeviceName(), propertyName ,NULL);
-    return true;
+    if (removeProperty(propertyName, errmsg) == 0)
+    {
+        IDDelete(getDeviceName(), propertyName ,NULL);
+        return true;
+    }
+    else
+        return false;
 }
 
 void INDI::DefaultDevice::defineNumber(INumberVectorProperty *nvp)
