@@ -182,6 +182,11 @@ public:
      */
     const char *getFrameTypeName(CCD_FRAME fType);
 
+    /**
+      * @brief Return CCD Info Property
+    */
+    INumberVectorProperty * getCCDInfo() { return &ImagePixelSizeNP; }
+
     /**
      * @brief setResolution set CCD Chip resolution
      * @param x width
@@ -206,12 +211,15 @@ public:
     void setBin(int hor, int ver);
 
     /**
-     * @brief setMaxBin Set Maximum CCD Chip binning
-     * @param max_hor Maximum horizontal binning
-     * @param max_ver Maximum vertical binning
+     * @brief setMinMaxStep for a number property element
+     * @param property Property name
+     * @param element Element name
+     * @param min Minimum element value
+     * @param max Maximum element value
+     * @param step Element step value
+     * @param sendToClient If true (default), the element limits are updated and is sent to the client. If false, the element limits are updated without getting sent to the client.
      */
-    void setMaxBin(int max_hor, int max_ver);
-
+    void setMinMaxStep(const char *property, const char *element, double min, double max, double step, bool sendToClient=true);
 
     /**
      * @brief setPixelSize Set CCD Chip pixel size
@@ -296,7 +304,7 @@ public:
     /**
      * @return True if CCD is currently exposing, false otherwise.
      */
-    bool isExposing() { return (ImageExposureNP->s == IPS_BUSY); }
+    bool isExposing() { return (ImageExposureNP.s == IPS_BUSY); }
 
 private:
 
@@ -323,38 +331,41 @@ private:
     int lastRapidY;
     char imageExtention[MAXINDIBLOBFMT];
 
-    INumberVectorProperty *ImageExposureNP;
+    INumberVectorProperty ImageExposureNP;
     INumber ImageExposureN[1];
 
-    ISwitchVectorProperty *AbortExposureSP;
+    ISwitchVectorProperty AbortExposureSP;
     ISwitch AbortExposureS[1];
 
-    INumberVectorProperty *ImageFrameNP;
+    INumberVectorProperty ImageFrameNP;
     INumber ImageFrameN[4];
 
-    INumberVectorProperty *ImageBinNP;
+    INumberVectorProperty ImageBinNP;
     INumber ImageBinN[2];
 
-    INumberVectorProperty *ImagePixelSizeNP;
+    INumberVectorProperty ImagePixelSizeNP;
     INumber ImagePixelSizeN[6];
 
     ISwitch FrameTypeS[5];
-    ISwitchVectorProperty *FrameTypeSP;
+    ISwitchVectorProperty FrameTypeSP;
 
     ISwitch CompressS[2];
-    ISwitchVectorProperty *CompressSP;
+    ISwitchVectorProperty CompressSP;
 
     IBLOB FitsB;
-    IBLOBVectorProperty *FitsBP;
+    IBLOBVectorProperty FitsBP;
 
     ISwitch RapidGuideS[2];
-    ISwitchVectorProperty *RapidGuideSP;
+    ISwitchVectorProperty RapidGuideSP;
 
     ISwitch RapidGuideSetupS[3];
-    ISwitchVectorProperty *RapidGuideSetupSP;
+    ISwitchVectorProperty RapidGuideSetupSP;
 
     INumber RapidGuideDataN[3];
-    INumberVectorProperty *RapidGuideDataNP;
+    INumberVectorProperty RapidGuideDataNP;
+
+    ISwitch                 ResetS[1];
+    ISwitchVectorProperty   ResetSP;
 
     friend class INDI::CCD;
 };
@@ -366,7 +377,7 @@ private:
    It also implements the interface to perform guiding. The class enable the ability to \e snoop on telescope equatorial coordinates and record them in the
    FITS file before upload. Developers need to subclass INDI::CCD to implement any driver for CCD cameras within INDI.
 
-\author Gerry Rozema, Jasem Mutlaq
+\author Jasem Mutlaq, Gerry Rozema
 */
 class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
 {
@@ -374,16 +385,28 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         CCD();
         virtual ~CCD();
 
+        /** \struct CCDCapability
+            \brief Holds the capabilities of the CCD. All fields must be initialized.
+        */
         typedef struct
         {
+            /** Does the CCD have a guide head? */
             bool hasGuideHead;
+            /** Does the CCD have an ST4-compatible port to send guide pulses? */
             bool hasST4Port;
+            /** Does the CCD have a mechanical or electronic shutter? */
             bool hasShutter;
+            /** Does the CCD have a cooler and temperature can be controlled? */
             bool hasCooler;
+            /** Does the CCD supprt binning opertation either in software or hardware? */
             bool canBin;
+            /** Can the CCD send a subframe of the full image? */
             bool canSubFrame;
+            /** Can the CCD abort exposure? */
             bool canAbort;
-        } Capability;
+            /** Does the CCD send image in bayer format? */
+            bool hasBayer;
+        } CCDCapability;
 
         virtual bool initProperties();
         virtual bool updateProperties();
@@ -395,8 +418,16 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
 
      protected:
 
-        Capability GetCapability() const { return capability;}
-        void SetCapability(Capability * cap);
+        /**
+         * @brief GetCCDCapability returns the CCD capabilities.
+         */
+        CCDCapability GetCCDCapability() const { return capability;}
+
+        /**
+         * @brief SetCCDCapability Set the CCD capabilities. Al fields must be initilized.
+         * @param cap pointer to CCDCapability struct.
+         */
+        void SetCCDCapability(CCDCapability * cap);
 
         /**
          * @return True if CCD can abort exposure. False otherwise.
@@ -433,6 +464,11 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
          */
         bool HasCooler() { return capability.hasCooler;}
 
+        /**
+         * @return True if CCD sends image data in bayer format. False otherwise.
+         */
+        bool HasBayer() { return capability.hasBayer;}
+
         /**
          * @brief Set CCD temperature
          * @param temperature CCD temperature in degrees celcius.
@@ -451,7 +487,8 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         */
         virtual bool StartExposure(float duration);
 
-        /** \brief Uploads target Chip exposed buffer as FITS to the client. Dervied classes should class this function when an exposure is complete.
+        /** \brief Uploads target Chip exposed buffer as FITS to the client. Dervied classes should class this functon when an exposure is complete.
+         * @param targetChip chip that contains upload image data
              \note This function is not implemented in INDI::CCD, it must be implemented in the child class
         */
         virtual bool ExposureComplete(CCDChip *targetChip);
@@ -627,6 +664,9 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         float ExposureTime;
         float GuiderExposureTime;
 
+        std::vector<std::string> FilterNames;
+        int CurrentFilterSlot;
+
         CCDChip PrimaryCCD;
         CCDChip GuideCCD;
 
@@ -634,17 +674,27 @@ class INDI::CCD : public INDI::DefaultDevice, INDI::GuiderInterface
         INumberVectorProperty EqNP;
         INumber EqN[2];
 
-        ITextVectorProperty *ActiveDeviceTP;
-        IText ActiveDeviceT[2];
+        ITextVectorProperty ActiveDeviceTP;
+        IText ActiveDeviceT[3];
 
         INumber                 TemperatureN[1];
         INumberVectorProperty   TemperatureNP;
 
-     private:
-        Capability capability;
+        IText BayerT[3];
+        ITextVectorProperty BayerTP;
 
-        bool uploadFile(CCDChip * targetChip, const void *fitsData, size_t totalBytes);
+        ISwitch UploadS[3];
+        ISwitchVectorProperty UploadSP;
+
+        IText   UploadSettingsT[2];
+        ITextVectorProperty UploadSettingsTP;
+
+     private:
+        CCDCapability capability;
+
+        bool uploadFile(CCDChip * targetChip, const void *fitsData, size_t totalBytes, bool sendImage, bool saveImage);
         void getMinMax(double *min, double *max, CCDChip *targetChip);
+        int getFileIndex(const char *dir, const char *prefix, const char *ext);
 
 
 };
