@@ -22,7 +22,9 @@
 
 INDI::Focuser::Focuser()
 {
+    controller = new INDI::Controller(this);
 
+    controller->setButtonCallback(buttonHelper);
 }
 
 INDI::Focuser::~Focuser()
@@ -53,6 +55,13 @@ bool INDI::Focuser::initProperties()
 
     addDebugControl();
 
+    controller->mapController("Focus In", "Focus In", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_1");
+    controller->mapController("Focus Out", "Focus Out", INDI::Controller::CONTROLLER_BUTTON, "BUTTON_2");
+
+    controller->initProperties();
+
+    setInterfaceDescriptor(FOCUSER_INTERFACE);
+
     return true;
 }
 
@@ -63,6 +72,7 @@ void INDI::Focuser::ISGetProperties (const char *dev)
 
     defineText(&PortTP);
 
+    controller->ISGetProperties(dev);
     return;
 }
 
@@ -73,18 +83,18 @@ bool INDI::Focuser::updateProperties()
         //  Now we add our focusser specific stuff
         defineSwitch(&FocusMotionSP);
 
-        if (variableSpeed)
+        if (capability.variableSpeed)
         {
             defineNumber(&FocusSpeedNP);
             defineNumber(&FocusTimerNP);
         }
-        if (canRelMove)
+        if (capability.canRelMove)
             defineNumber(&FocusRelPosNP);
-        if (canAbsMove)            
+        if (capability.canAbsMove)
             defineNumber(&FocusAbsPosNP);
-        if (canAbort)
+        if (capability.canAbort)
             defineSwitch(&AbortSP);
-        if (canAbsMove)
+        if (capability.canAbsMove)
         {
             defineNumber(&PresetNP);
             defineSwitch(&PresetGotoSP);
@@ -92,23 +102,25 @@ bool INDI::Focuser::updateProperties()
     } else
     {
         deleteProperty(FocusMotionSP.name);
-        if (variableSpeed)
+        if (capability.variableSpeed)
         {
             deleteProperty(FocusSpeedNP.name);
             deleteProperty(FocusTimerNP.name);
         }
-        if (canRelMove)
+        if (capability.canRelMove)
             deleteProperty(FocusRelPosNP.name);
-        if (canAbsMove)
+        if (capability.canAbsMove)
             deleteProperty(FocusAbsPosNP.name);
-        if (canAbort)
+        if (capability.canAbort)
             deleteProperty(AbortSP.name);
-        if (canAbsMove)
+        if (capability.canAbsMove)
         {
             deleteProperty(PresetNP.name);
             deleteProperty(PresetGotoSP.name);
         }
     }
+
+    controller->updateProperties();
     return true;
 }
 
@@ -124,7 +136,7 @@ bool INDI::Focuser::ISNewNumber (const char *dev, const char *name, double value
             PresetNP.s = IPS_OK;
             IDSetNumber(&PresetNP, NULL);
 
-            saveConfig();
+            //saveConfig();
 
             return true;
         }
@@ -134,20 +146,18 @@ bool INDI::Focuser::ISNewNumber (const char *dev, const char *name, double value
 
     }
 
-
     return DefaultDevice::ISNewNumber(dev,name,values,names,n);
 }
 
 bool INDI::Focuser::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
-
     if(strcmp(dev,getDeviceName())==0)
     {
         if (!strcmp(PresetGotoSP.name, name))
         {
             IUUpdateSwitch(&PresetGotoSP, states, names, n);
             int index = IUFindOnSwitchIndex(&PresetGotoSP);
-            int rc = MoveAbs(PresetN[index].value);
+            int rc = MoveAbsFocuser(PresetN[index].value);
             if (rc >= 0)
             {
                 PresetGotoSP.s = IPS_OK;
@@ -166,6 +176,8 @@ bool INDI::Focuser::ISNewSwitch (const char *dev, const char *name, ISState *sta
 
     }
 
+    controller->ISNewSwitch(dev, name, states, names, n);
+
     //  Nobody has claimed this, so, ignore it
     return DefaultDevice::ISNewSwitch(dev,name,states,names,n);
 }
@@ -183,11 +195,15 @@ bool INDI::Focuser::ISNewText (const char *dev, const char *name, char *texts[],
         }
     }
 
+    controller->ISNewText(dev, name, texts, names, n);
+
     return DefaultDevice::ISNewText(dev, name, texts, names, n);
 }
 
 bool INDI::Focuser::ISSnoopDevice (XMLEle *root)
 {
+    controller->ISSnoopDevice(root);
+
     return INDI::DefaultDevice::ISSnoopDevice(root);
 }
 
@@ -196,6 +212,98 @@ bool INDI::Focuser::saveConfigItems(FILE *fp)
     IUSaveConfigText(fp, &PortTP);
     IUSaveConfigNumber(fp, &PresetNP);
 
+    controller->saveConfigItems(fp);
+
     return true;
 }
 
+void INDI::Focuser::buttonHelper(const char *button_n, ISState state, void *context)
+{
+     static_cast<INDI::Focuser *>(context)->processButton(button_n, state);
+}
+
+void INDI::Focuser::processButton(const char * button_n, ISState state)
+{
+    //ignore OFF
+    if (state == ISS_OFF)
+        return;
+
+    FocusTimerN[0].value = lastTimerValue;
+
+    int rc=0;
+    // Focus In
+    if (!strcmp(button_n, "Focus In"))
+    {
+        if (FocusMotionS[FOCUS_INWARD].s != ISS_ON)
+        {
+            FocusMotionS[FOCUS_INWARD].s = ISS_ON;
+            FocusMotionS[FOCUS_OUTWARD].s = ISS_OFF;
+            IDSetSwitch(&FocusMotionSP, NULL);
+        }
+
+        if (capability.variableSpeed)
+        {
+           rc = MoveFocuser(FOCUS_INWARD, FocusSpeedN[0].value, FocusTimerN[0].value);
+            if (rc == 0)
+                FocusTimerNP.s = IPS_OK;
+            else if (rc == 1)
+                FocusTimerNP.s = IPS_BUSY;
+            else
+                FocusTimerNP.s = IPS_ALERT;
+
+            IDSetNumber(&FocusTimerNP,NULL);
+        }
+        else if (capability.canRelMove)
+        {
+            rc=MoveRelFocuser(FOCUS_INWARD, FocusRelPosN[0].value);
+            if (rc == 0)
+            {
+               FocusRelPosNP.s=IPS_OK;
+               IDSetNumber(&FocusRelPosNP, "Focuser moved %d steps inward", (int) FocusRelPosN[0].value);
+               IDSetNumber(&FocusAbsPosNP, NULL);
+            }
+            else if (rc == 1)
+            {
+                 FocusRelPosNP.s=IPS_BUSY;
+                 IDSetNumber(&FocusAbsPosNP, "Focuser is moving %d steps inward...", (int) FocusRelPosN[0].value);
+            }
+        }
+    }
+    else if (!strcmp(button_n, "Focus Out"))
+    {
+        if (FocusMotionS[FOCUS_OUTWARD].s != ISS_ON)
+        {
+            FocusMotionS[FOCUS_INWARD].s = ISS_OFF;
+            FocusMotionS[FOCUS_OUTWARD].s = ISS_ON;
+            IDSetSwitch(&FocusMotionSP, NULL);
+        }
+
+        if (capability.variableSpeed)
+        {
+           rc = MoveFocuser(FOCUS_OUTWARD, FocusSpeedN[0].value, FocusTimerN[0].value);
+            if (rc == 0)
+                FocusTimerNP.s = IPS_OK;
+            else if (rc == 1)
+                FocusTimerNP.s = IPS_BUSY;
+            else
+                FocusTimerNP.s = IPS_ALERT;
+
+            IDSetNumber(&FocusTimerNP,NULL);
+        }
+        else if (capability.canRelMove)
+        {
+            rc=MoveRelFocuser(FOCUS_OUTWARD, FocusRelPosN[0].value);
+            if (rc == 0)
+            {
+               FocusRelPosNP.s=IPS_OK;
+               IDSetNumber(&FocusRelPosNP, "Focuser moved %d steps outward", (int) FocusRelPosN[0].value);
+               IDSetNumber(&FocusAbsPosNP, NULL);
+            }
+            else if (rc == 1)
+            {
+                 FocusRelPosNP.s=IPS_BUSY;
+                 IDSetNumber(&FocusAbsPosNP, "Focuser is moving %d steps outward...", (int) FocusRelPosN[0].value);
+            }
+        }
+    }
+}
