@@ -25,7 +25,8 @@
 INDI::Telescope::Telescope()
 {
     //ctor
-
+    capability.canPark = capability.canSync = capability.canAbort = false;
+    last_we_motion = last_ns_motion = -1;
 }
 
 INDI::Telescope::~Telescope()
@@ -50,37 +51,32 @@ bool INDI::Telescope::initProperties()
     IUFillNumber(&LocationN[2],"ELEV","Elevation (m)","%g",-200,10000,0,0 );
     IUFillNumberVector(&LocationNP,LocationN,3,getDeviceName(),"GEOGRAPHIC_COORD","Scope Location",SITE_TAB,IP_RW,60,IPS_OK);
 
-    IUFillSwitch(&CoordS[0],"TRACK","Track",ISS_OFF);
+    IUFillSwitch(&CoordS[0],"TRACK","Track",ISS_ON);
     IUFillSwitch(&CoordS[1],"SLEW","Slew",ISS_OFF);
     IUFillSwitch(&CoordS[2],"SYNC","Sync",ISS_OFF);
 
-    if (canSync())
+    if (capability.canSync)
         IUFillSwitchVector(&CoordSP,CoordS,3,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
     else
         IUFillSwitchVector(&CoordSP,CoordS,2,getDeviceName(),"ON_COORD_SET","On Set",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
 
-    IUFillSwitch(&ConfigS[0], "CONFIG_LOAD", "Load", ISS_OFF);
-    IUFillSwitch(&ConfigS[1], "CONFIG_SAVE", "Save", ISS_OFF);
-    IUFillSwitch(&ConfigS[2], "CONFIG_DEFAULT", "Default", ISS_OFF);
-    IUFillSwitchVector(&ConfigSP, ConfigS, 3, getDeviceName(), "CONFIG_PROCESS", "Configuration", "Options", IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
-
 
     IUFillSwitch(&ParkS[0],"PARK","Park",ISS_OFF);
-    IUFillSwitchVector(&ParkSP,ParkS,1,getDeviceName(),"TELESCOPE_PARK","Park",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(&ParkSP,ParkS,1,getDeviceName(),"TELESCOPE_PARK","Park",MAIN_CONTROL_TAB,IP_RW,ISR_ATMOST1,60,IPS_IDLE);
 
     IUFillSwitch(&AbortS[0],"ABORT","Abort",ISS_OFF);
-    IUFillSwitchVector(&AbortSP,AbortS,1,getDeviceName(),"TELESCOPE_ABORT_MOTION","Abort Motion",MAIN_CONTROL_TAB,IP_RW,ISR_1OFMANY,60,IPS_IDLE);
+    IUFillSwitchVector(&AbortSP,AbortS,1,getDeviceName(),"TELESCOPE_ABORT_MOTION","Abort Motion",MAIN_CONTROL_TAB,IP_RW,ISR_ATMOST1,60,IPS_IDLE);
 
     IUFillText(&PortT[0],"PORT","Port","/dev/ttyUSB0");
     IUFillTextVector(&PortTP,PortT,1,getDeviceName(),"DEVICE_PORT","Ports",OPTIONS_TAB,IP_RW,60,IPS_IDLE);
 
     IUFillSwitch(&MovementNSS[MOTION_NORTH], "MOTION_NORTH", "North", ISS_OFF);
     IUFillSwitch(&MovementNSS[MOTION_SOUTH], "MOTION_SOUTH", "South", ISS_OFF);
-    IUFillSwitchVector(&MovementNSSP, MovementNSS, 2, getDeviceName(),"TELESCOPE_MOTION_NS", "North/South", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&MovementNSSP, MovementNSS, 2, getDeviceName(),"TELESCOPE_MOTION_NS", "North/South", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     IUFillSwitch(&MovementWES[MOTION_WEST], "MOTION_WEST", "West", ISS_OFF);
     IUFillSwitch(&MovementWES[MOTION_EAST], "MOTION_EAST", "East", ISS_OFF);
-    IUFillSwitchVector(&MovementWESP, MovementWES, 2, getDeviceName(),"TELESCOPE_MOTION_WE", "West/East", MOTION_TAB, IP_RW, ISR_1OFMANY, 60, IPS_IDLE);
+    IUFillSwitchVector(&MovementWESP, MovementWES, 2, getDeviceName(),"TELESCOPE_MOTION_WE", "West/East", MOTION_TAB, IP_RW, ISR_ATMOST1, 60, IPS_IDLE);
 
     IUFillNumber(&ScopeParametersN[0],"TELESCOPE_APERTURE","Aperture (mm)","%g",50,4000,0,0.0);
     IUFillNumber(&ScopeParametersN[1],"TELESCOPE_FOCAL_LENGTH","Focal Length (mm)","%g",100,10000,0,0.0 );
@@ -90,6 +86,8 @@ bool INDI::Telescope::initProperties()
 
     TrackState=SCOPE_PARKED;
 
+    setInterfaceDescriptor(TELESCOPE_INTERFACE);
+
     return true;
 }
 
@@ -98,23 +96,20 @@ void INDI::Telescope::ISGetProperties (const char *dev)
     //  First we let our parent populate
     DefaultDevice::ISGetProperties(dev);
 
-    //  We may need the port set before we can connect
-    //IDDefText(&PortTP,NULL);
     defineText(&PortTP);
-    defineSwitch(&ConfigSP);
 
     if(isConnected())
     {
         //  Now we add our telescope specific stuff
         defineSwitch(&CoordSP);
         defineNumber(&EqNP);
-        defineSwitch(&AbortSP);
+        if (capability.canAbort)
+            defineSwitch(&AbortSP);
         defineText(&TimeTP);
         defineNumber(&LocationNP);
         defineSwitch(&ParkSP);
         defineSwitch(&MovementNSSP);
         defineSwitch(&MovementWESP);
-        defineSwitch(&ConfigSP);
         defineNumber(&ScopeParametersNP);
 
     }
@@ -129,12 +124,13 @@ bool INDI::Telescope::updateProperties()
         //  Now we add our telescope specific stuff
         defineSwitch(&CoordSP);
         defineNumber(&EqNP);
-        defineSwitch(&AbortSP);
+        if (capability.canAbort)
+            defineSwitch(&AbortSP);
         defineSwitch(&MovementNSSP);
         defineSwitch(&MovementWESP);
         defineText(&TimeTP);
         defineNumber(&LocationNP);
-        if (canPark())
+        if (capability.canPark)
             defineSwitch(&ParkSP);
         defineNumber(&ScopeParametersNP);
 
@@ -143,12 +139,13 @@ bool INDI::Telescope::updateProperties()
     {
         deleteProperty(CoordSP.name);
         deleteProperty(EqNP.name);
-        deleteProperty(AbortSP.name);
+        if (capability.canAbort)
+            deleteProperty(AbortSP.name);
         deleteProperty(MovementNSSP.name);
         deleteProperty(MovementWESP.name);
         deleteProperty(TimeTP.name);
         deleteProperty(LocationNP.name);
-        if (canPark())
+        if (capability.canPark)
             deleteProperty(ParkSP.name);
         deleteProperty(ScopeParametersNP.name);
     }
@@ -214,8 +211,10 @@ bool INDI::Telescope::Sync(double ra,double dec)
     return false;
 }
 
-bool INDI::Telescope::MoveNS(TelescopeMotionNS dir)
+bool INDI::Telescope::MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command)
 {
+    INDI_UNUSED(dir);
+    INDI_UNUSED(command);
     DEBUG(Logger::DBG_ERROR, "Mount does not support North/South motion.");
     IUResetSwitch(&MovementNSSP);
     MovementNSSP.s = IPS_IDLE;
@@ -223,8 +222,10 @@ bool INDI::Telescope::MoveNS(TelescopeMotionNS dir)
     return false;
 }
 
-bool INDI::Telescope::MoveWE(TelescopeMotionWE dir)
+bool INDI::Telescope::MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command)
 {
+    INDI_UNUSED(dir);
+    INDI_UNUSED(command);
     DEBUG(Logger::DBG_ERROR,"Mount does not support West/East motion.");
     IUResetSwitch(&MovementWESP);
     MovementWESP.s = IPS_IDLE;
@@ -326,13 +327,18 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
                 //  perform the goto
                 //  Ok, lets see if we should be doing a goto
                 //  or a sync
-                if (canSync())
+                if (capability.canSync)
                 {
                     ISwitch *sw;
                     sw=IUFindSwitch(&CoordSP,"SYNC");
                     if((sw != NULL)&&( sw->s==ISS_ON ))
                     {
                        rc=Sync(ra,dec);
+                       if (rc)
+                           CoordSP .s = IPS_OK;
+                       else
+                           CoordSP.s = IPS_ALERT;
+                       IDSetSwitch(&CoordSP, NULL);
                        return rc;
                     }
                 }
@@ -341,6 +347,11 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
                 ParkSP.s=IPS_IDLE;
                 IUResetSwitch(&ParkSP);
                 rc=Goto(ra,dec);
+                if (rc)
+                    CoordSP .s = IPS_OK;
+                else
+                    CoordSP.s = IPS_ALERT;
+                IDSetSwitch(&CoordSP, NULL);
 
                 //  Ok, now we have to put our switches back
             }
@@ -385,8 +396,6 @@ bool INDI::Telescope::ISNewNumber (const char *dev, const char *name, double val
             IUUpdateNumber(&ScopeParametersNP,values,names,n);
             IDSetNumber(&ScopeParametersNP,NULL);
 
-            saveConfig();
-
             return true;
         }
 
@@ -415,7 +424,29 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
 
         if(strcmp(name,"TELESCOPE_PARK")==0)
         {
-            Park();
+            ParkS[0].s = ISS_OFF;
+
+            if (ParkSP.s == IPS_BUSY)
+            {
+                IDSetSwitch(&ParkSP, NULL);
+                return true;
+            }
+
+            bool rc = Park();
+            if (rc)
+            {
+                if (TrackState == SCOPE_PARKING)
+                {
+                     ParkS[0].s = ISS_ON;
+                     ParkSP.s = IPS_BUSY;
+                }
+                else
+                    ParkSP.s = IPS_OK;
+            }
+            else
+                ParkSP.s = IPS_ALERT;
+
+            IDSetSwitch(&ParkSP, NULL);
             return true;
         }
 
@@ -423,12 +454,36 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
         {
             IUUpdateSwitch(&MovementNSSP,states,names,n);
 
-            MovementNSSP.s = IPS_BUSY;
+            int current_motion = IUFindOnSwitchIndex(&MovementNSSP);
 
-            if (MovementNSS[MOTION_NORTH].s == ISS_ON)
-                MoveNS(MOTION_NORTH);
+            // if same move requested, return
+            if ( MovementNSSP.s == IPS_BUSY && current_motion == last_ns_motion)
+                return true;
+
+            // Time to stop motion
+            if (current_motion == -1 || (last_ns_motion != -1 && current_motion != last_ns_motion))
+            {
+                if (MoveNS(last_ns_motion == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_STOP))
+                {
+                    IUResetSwitch(&MovementNSSP);
+                    MovementNSSP.s = IPS_IDLE;
+                    last_ns_motion = -1;
+                }
+                else
+                    MovementNSSP.s = IPS_ALERT;
+            }
             else
-                MoveNS(MOTION_SOUTH);
+            {
+                if (MoveNS(current_motion == 0 ? MOTION_NORTH : MOTION_SOUTH, MOTION_START))
+                {
+                    MovementNSSP.s = IPS_BUSY;
+                    last_ns_motion = current_motion;
+                }
+                else
+                    MovementNSSP.s = IPS_ALERT;
+            }
+
+            IDSetSwitch(&MovementNSSP, NULL);
 
             return true;
         }
@@ -437,12 +492,36 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
         {
             IUUpdateSwitch(&MovementWESP,states,names,n);
 
-            MovementWESP.s = IPS_BUSY;
+            int current_motion = IUFindOnSwitchIndex(&MovementWESP);
 
-            if (MovementWES[MOTION_WEST].s == ISS_ON)
-                MoveWE(MOTION_WEST);
+            // if same move requested, return
+            if ( MovementWESP.s == IPS_BUSY && current_motion == last_we_motion)
+                return true;
+
+            // Time to stop motion
+            if (current_motion == -1 || (last_we_motion != -1 && current_motion != last_we_motion))
+            {
+                if (MoveWE(last_we_motion == 0 ? MOTION_WEST : MOTION_EAST, MOTION_STOP))
+                {
+                    IUResetSwitch(&MovementWESP);
+                    MovementWESP.s = IPS_IDLE;
+                    last_we_motion = -1;
+                }
+                else
+                    MovementWESP.s = IPS_ALERT;
+            }
             else
-                MoveWE(MOTION_EAST);
+            {
+                if (MoveWE(current_motion == 0 ? MOTION_WEST : MOTION_EAST, MOTION_START))
+                {
+                    MovementWESP.s = IPS_BUSY;
+                    last_we_motion = current_motion;
+                }
+                else
+                    MovementWESP.s = IPS_ALERT;
+            }
+
+            IDSetSwitch(&MovementWESP, NULL);
 
             return true;
         }
@@ -482,6 +561,7 @@ bool INDI::Telescope::ISNewSwitch (const char *dev, const char *name, ISState *s
                     IDSetNumber(&EqNP, NULL);
                 }
 
+                last_ns_motion=last_we_motion=-1;
                 TrackState = SCOPE_IDLE;
             }
             else
@@ -600,16 +680,6 @@ bool INDI::Telescope::Park()
     return false;
 }
 
-bool INDI::Telescope::canSync()
-{
-    return false;
-}
-
-bool INDI::Telescope::canPark()
-{
-    return false;
-}
-
 bool INDI::Telescope::updateTime(ln_date *utc, double utc_offset)
 {
     INDI_UNUSED(utc);
@@ -626,3 +696,10 @@ bool INDI::Telescope::updateLocation(double latitude, double longitude, double e
 
     return true;
 }
+
+void INDI::Telescope::SetTelescopeCapability(TelescopeCapability *cap)
+{
+    capability.canPark      = cap->canPark;
+    capability.canSync      = cap->canSync;
+    capability.canAbort     = cap->canAbort;
+}
