@@ -51,9 +51,34 @@ class INDI::Telescope : public INDI::DefaultDevice
         Telescope();
         virtual ~Telescope();
 
+        /** \struct TelescopeCapability
+            \brief Holds the capabilities of a telescope.
+        */
+        typedef struct
+        {
+            /** Can the telescope sync to specific coordinates? */
+            bool canSync;
+            /** Can the telescope park? */
+            bool canPark;
+            /** Can the telescope abort motion? */
+            bool canAbort;
+        } TelescopeCapability;
+
+        /**
+         * @brief GetTelescopeCapability returns the capability of the Telescope
+         */
+        TelescopeCapability GetTelescopeCapability() const { return capability;}
+
+        /**
+         * @brief SetTelescopeCapability sets the Telescope capabilities. All capabilities must be initialized.
+         * @param cap pointer to Telescope capability struct.
+         */
+        void SetTelescopeCapability(TelescopeCapability * cap);
+
         enum TelescopeStatus { SCOPE_IDLE, SCOPE_SLEWING, SCOPE_TRACKING, SCOPE_PARKING, SCOPE_PARKED };
         enum TelescopeMotionNS { MOTION_NORTH, MOTION_SOUTH };
         enum TelescopeMotionWE { MOTION_WEST, MOTION_EAST };
+        enum TelescopeMotionCommand { MOTION_START, MOTION_STOP };
 
         virtual bool ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n);
         virtual bool ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n);
@@ -110,35 +135,27 @@ class INDI::Telescope : public INDI::DefaultDevice
         */
         virtual bool Goto(double ra,double dec)=0;
 
-        /** \brief Does the mount support sync?
-         *  \return True if sync is supported, false otherwise.
-         *\note This function is not implemented in INDI::Telescope, it must be implemented in the child class
-        */
-        virtual bool canSync();
-
         /** \brief Set the telescope current RA and DEC coordinates to the supplied RA and DEC coordinates
             \return True if successful, false otherewise
             *\note This function implemented INDI::Telescope always returns false. Override the function to return true.
         */
         virtual bool Sync(double ra,double dec);
 
-        /** \brief Move the telescope in the direction dir.
+        /** \brief Start or Stop the telescope motion in the direction dir.
+         *  \param dir direction of motion
+         *  \param command Start or Stop command
             \return True if successful, false otherewise
             \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
         */
-        virtual bool MoveNS(TelescopeMotionNS dir);
+        virtual bool MoveNS(TelescopeMotionNS dir, TelescopeMotionCommand command);
 
         /** \brief Move the telescope in the direction dir.
+            \param dir direction of motion
+            \param command Start or Stop command
             \return True if successful, false otherewise
             \note This function is not implemented in INDI::Telescope, it must be implemented in the child class
         */
-        virtual bool MoveWE(TelescopeMotionWE dir);
-
-        /** \brief Does the mount support park?
-         *  \return True if park is supported, false otherwise.
-         *\note This function defaults to return false unless subclassed by the child class.
-        */
-        virtual bool canPark();
+        virtual bool MoveWE(TelescopeMotionWE dir, TelescopeMotionCommand command);
 
         /** \brief Park the telescope to its home position.
             \return True if successful, false otherewise
@@ -190,9 +207,6 @@ class INDI::Telescope : public INDI::DefaultDevice
         ISwitchVectorProperty CoordSP; //  A switch vector that stores how we should readct
         ISwitch CoordS[3];              //  On a coord_set message, sync, or slew
 
-        ISwitchVectorProperty ConfigSP; //  A switch vector that stores how we should readct
-        ISwitch ConfigS[3];              //  On a coord_set message, sync, or slew
-
         INumberVectorProperty LocationNP;   //  A number vector that stores lattitude and longitude
         INumber LocationN[3];
 
@@ -214,6 +228,9 @@ class INDI::Telescope : public INDI::DefaultDevice
         IText TimeT[2];
         ITextVectorProperty TimeTP;
 
+        TelescopeCapability capability;
+        int last_we_motion, last_ns_motion;
+
 };
 
 #endif // INDI::Telescope_H
