@@ -307,6 +307,81 @@ void bayer16_2_rgb24(unsigned short *dst, unsigned short *src, long int WIDTH, l
 
 }
 
+
+void bayer_rggb_2rgb24(unsigned char *dst, unsigned char *src, long int WIDTH, long int HEIGHT)
+{
+  long int i;
+  unsigned char *rawpt, *scanpt;
+  long int size;
+  
+  rawpt = src;
+  scanpt = dst;
+  size = WIDTH*HEIGHT;
+   
+        
+  for ( i = 0; i < size; i++ ) {
+    if ( (i/WIDTH) % 2 == 0 ) {//wenn zeile grade
+      if ( (i % 2) == 0 ) { //spalte gerade
+ /* B */
+ if ( (i > WIDTH) && ((i % WIDTH) > 0) ) { // wenn nicht erste zeile oder linke spalte
+   *scanpt++ = *rawpt;     /* R */
+   *scanpt++ = (*(rawpt-1)+*(rawpt+1)+
+   *(rawpt+WIDTH)+*(rawpt-WIDTH))/4; /* G */
+   *scanpt++ = (*(rawpt-WIDTH-1)+*(rawpt-WIDTH+1)+
+   *(rawpt+WIDTH-1)+*(rawpt+WIDTH+1))/4;  /* B */
+ } else {
+   /* first line or left column */
+   *scanpt++ = *rawpt;   /* R */
+   *scanpt++ = (*(rawpt+1)+*(rawpt+WIDTH))/2; /* G */
+   *scanpt++ = *(rawpt+WIDTH+1);   /* B */
+ }
+      } else {
+ /* (B)G */
+ if ( (i > WIDTH) && ((i % WIDTH) < (WIDTH-1)) ) {
+   *scanpt++ =(*(rawpt-1)+*(rawpt+1))/2;   /* R */
+   *scanpt++ = *rawpt;     /* G */
+   *scanpt++ =  (*(rawpt+WIDTH)+*(rawpt-WIDTH))/2;/* B */
+ } else {
+   /* first line or right column */
+   *scanpt++ =  *(rawpt-1);/* R */
+   *scanpt++ = *rawpt;  /* G */
+   *scanpt++ = *(rawpt+WIDTH); /* B */
+ }
+      }
+    } else {
+      if ( (i % 2) == 0 ) {
+ /* G(R) */
+ if ( (i < (WIDTH*(HEIGHT-1))) && ((i % WIDTH) > 0) ) {
+   *scanpt++ =  (*(rawpt+WIDTH)+*(rawpt-WIDTH))/2;  /* R */
+   *scanpt++ = *rawpt;     /* G */
+   *scanpt++ = (*(rawpt-1)+*(rawpt+1))/2;/* B */
+ } else {
+   /* bottom line or left column */
+   *scanpt++ =  *(rawpt-WIDTH); /* R */
+   *scanpt++ = *rawpt;   /* G */
+   *scanpt++ = *(rawpt+1);  /* B */
+ }
+      } else {
+ /* R */
+ if ( i < (WIDTH*(HEIGHT-1)) && ((i % WIDTH) < (WIDTH-1)) ) {
+   *scanpt++ =(*(rawpt-WIDTH-1)+*(rawpt-WIDTH+1)+
+   *(rawpt+WIDTH-1)+*(rawpt+WIDTH+1))/4;     /* R */
+   *scanpt++ = (*(rawpt-1)+*(rawpt+1)+
+   *(rawpt-WIDTH)+*(rawpt+WIDTH))/4; /* G */
+   *scanpt++ =  *rawpt; /* B */
+ } else {
+   /* bottom line or right column */
+   *scanpt++ = *(rawpt-WIDTH-1);    /* R */
+   *scanpt++ = (*(rawpt-1)+*(rawpt-WIDTH))/2; /* G */
+   *scanpt++ =  *rawpt; /* B */
+ }
+      }
+    }
+    rawpt++;
+  }
+}
+
+
 /*
  * mjpegtoyuv420p
  *
