@@ -1,5 +1,6 @@
 /*
     Copyright (C) 2005 by Jasem Mutlaq <mutlaqja@ikarustech.com>
+    Copyright (C) 2013 Geehalel (geehalel@gmail.com)
 
     Based on V4L 2 Example
     http://v4l2spec.bytesex.org/spec-single/v4l2.html#CAPTURE-EXAMPLE
@@ -27,11 +28,25 @@
 #include <stdlib.h>
 //#include "videodev2.h"
 #include <linux/videodev2.h>
-#include "eventloop.h"
-#include "indidevapi.h"
+#include <eventloop.h>
+#include <indidevapi.h>
+// this adds add dependency to indidriver for v4l_legacy, meade_lpi
+
+// Can't use logger as legacy drivers don't use defaultdevice
+//#include <indilogger.h>
+#include "v4l2_decode/v4l2_decode.h"
+// for direct recording
+#include "v4l2_record/v4l2_record.h"
 
 #define VIDEO_COMPRESSION_LEVEL		4
 
+enum {
+	LX_ACTIVE = 0,
+	LX_TRIGGERED,
+	LX_ACCUMULATING
+};
+
+
 class V4L2_Base
 {
   public:
@@ -66,11 +81,11 @@ class V4L2_Base
   int (V4L2_Base::*setframerate)(struct v4l2_fract frate, char *errmsg);
   struct v4l2_fract (V4L2_Base::*getframerate)();
 
-  void allocBuffers();
   unsigned char * getY();
   unsigned char * getU();
   unsigned char * getV();
   unsigned char * getColorBuffer();
+  unsigned char * getRGBBuffer();
 
   void registerCallback(WPF *fp, void *ud);
 
@@ -78,6 +93,7 @@ class V4L2_Base
   int stop_capturing(char *errmsg);
   static void newFrame(int fd, void *p);
   
+  void setDropFrame(bool enable) { dropFrameEnabled = enable;}
   void enumerate_ctrl (void);
   void enumerate_menu (void);
   bool enumerate_ext_ctrl (void);
@@ -100,6 +116,16 @@ class V4L2_Base
   int setcroprect(int x, int y, int w, int h, char *errmsg);
   struct v4l2_rect getcroprect();
 
+
+
+  void setlxstate( short s ) { lxstate = s; }
+  short getlxstate() { return lxstate; }
+  bool isstreamactive() { return streamactive; }
+
+  void doDecode(bool);
+  void setRecorder(V4L2_Recorder *r);
+  void doRecord(bool);
+
   protected:
 
   int xioctl(int fd, int request, void *arg);
@@ -116,13 +142,13 @@ class V4L2_Base
   void init_read(unsigned int buffer_size);
 
   void findMinMax();
+
   
   /* Frame rate */
   int stdsetframerate(struct v4l2_fract frate, char *errmsg);
   int pwcsetframerate(struct v4l2_fract frate, char *errmsg);
   struct v4l2_fract stdgetframerate();
 
-
   struct v4l2_capability cap;
   struct v4l2_cropcap cropcap;
   struct v4l2_crop crop;
@@ -134,6 +160,9 @@ class V4L2_Base
   bool cropset;
   bool cansetrate;
   bool streamedonce;
+  bool streamactive;
+  
+  short lxstate;
 
   struct v4l2_queryctrl queryctrl;
   struct v4l2_querymenu querymenu;
@@ -148,13 +177,21 @@ class V4L2_Base
   unsigned int  n_buffers;
   bool reallocate_buffers;
   bool		dropFrame;
+  bool      dropFrameEnabled;
 
   
   struct v4l2_fract frameRate;
   int  xmax, xmin, ymax, ymin;
   int  selectCallBackID;
-  unsigned char * YBuf,*UBuf,*VBuf, *yuvBuffer, *colorBuffer, *rgb24_buffer, *cropbuf;
+  //unsigned char * YBuf,*UBuf,*VBuf, *yuvBuffer, *colorBuffer, *rgb24_buffer, *cropbuf;
   
+  V4L2_Decode *v4l2_decode;
+  V4L2_Decoder *decoder;
+  bool dodecode;
+
+  V4L2_Recorder *recorder;
+  bool dorecord;
+
   friend class V4L2_Driver;
 };
    
